/*
 *******************************************************************************
 *
 *  Copyright 2024 RIEGL Laser Measurement Systems
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *  SPDX-License-Identifier: Apache-2.0
 *
 *******************************************************************************
 */
/*!
 *******************************************************************************
 *
 * \author  RIEGL LMS GmbH, Austria
 * \brief   Description of RIEGL RDB 2 database meta data items.
 * \version 2015-10-27/AW: Initial version
 * \version 2015-11-25/AW: Item "Geo Tag" added
 * \version 2016-10-27/AW: Item "Voxel Information" added
 * \version 2016-11-17/AW: Item "Voxel Information" updated
 * \version 2016-12-12/AW: Item "Range Statistics" added
 * \version 2017-03-08/AW: Item "Plane Patch Statistics" added
 * \version 2017-04-05/AW: Items "Atmosphere" and "Geometric Scale Factor" added
 * \version 2017-08-22/AW: Items for waveform sample block and value files added
 * \version 2017-10-24/AW: Item "Gaussian Decomposition" added
 * \version 2017-11-13/AW: Item "riegl.scan_pattern" updated
 * \version 2017-11-21/AW: Item "riegl.trajectory_info" added
 * \version 2018-01-11/AW: Item "riegl.beam_geometry" added
 * \version 2018-01-15/AW: Item "riegl.reflectance_calculation" added
 * \version 2018-01-15/AW: Item "riegl.near_range_correction" added
 * \version 2018-01-15/AW: Item "riegl.device_geometry" added
 * \version 2018-02-13/AW: Item "riegl.notch_filter" added
 * \version 2018-03-08/AW: Item "riegl.window_echo_correction" added
 * \version 2018-03-15/AW: Item "riegl.pulse_position_modulation" added
 * \version 2018-05-24/AW: Item "riegl.pixel_info" added
 * \version 2018-06-08/AW: Item "riegl.shot_info" added
 * \version 2018-06-08/AW: Item "riegl.echo_info" added
 * \version 2018-06-14/AW: Item "riegl.mta_settings" added
 * \version 2018-06-14/AW: Item "riegl.receiver_internals" added
 * \version 2018-06-14/AW: Item "riegl.device_output_limits" added
 * \version 2018-06-26/AW: Schema: replace "number" with "integer" if applicable
 * \version 2018-07-09/AW: Item "riegl.pose_estimation" added
 * \version 2018-07-09/AW: Item "riegl.pose_sensors" added
 * \version 2018-09-20/AW: Item "riegl.pointcloud_info" added
 * \version 2018-11-08/AW: Item "riegl.scan_pattern" updated
 * \version 2018-11-13/AW: Item "riegl.receiver_internals" updated
 * \version 2019-03-06/AW: Item "riegl.receiver_internals" updated
 * \version 2019-03-21/AW: Item "riegl.device_geometry" updated
 * \version 2019-04-15/AW: Item "riegl.point_attribute_groups" added
 * \version 2019-04-30/AW: Item "riegl.waveform_settings" added
 * \version 2019-10-03/AW: Item "riegl.angular_notch_filter" added
 * \version 2019-10-03/AW: Item "riegl.noise_estimates" added
 * \version 2019-10-25/AW: Item "riegl.window_analysis" added
 * \version 2019-11-06/AW: Item "riegl.georeferencing_parameters" added
 * \version 2019-11-27/AW: Item "riegl.plane_patch_matching" added
 * \version 2019-12-13/AW: Items for tie-/control objects added
 * \version 2019-12-19/AW: Items for tie-/control objects added
 * \version 2020-02-04/AW: Item "riegl.detection_probability" added
 * \version 2020-02-04/AW: Item "riegl.licenses" added
 * \version 2020-04-27/AW: Item "riegl.waveform_info" updated (schema+example)
 * \version 2020-09-03/AW: Item "riegl.reflectance_correction" added
 * \version 2020-09-10/AW: Item "riegl.device_geometry_passive_channel" added
 * \version 2020-09-25/AW: Item "riegl.georeferencing_parameters" updated
 * \version 2020-09-25/AW: Item "riegl.trajectory_info" updated
 * \version 2020-09-29/AW: Item "riegl.temperature_calculation" added
 * \version 2020-10-23/AW: Item "riegl.exponential_decomposition" added (#3709)
 * \version 2020-11-30/AW: Item "riegl.notch_filter" updated (schema)
 * \version 2020-12-02/AW: Item "riegl.georeferencing_parameters" updated (schema)
 * \version 2021-02-02/AW: Item "riegl.plane_slope_class_info" added (rdbplanes/#7)
 * \version 2021-02-16/AW: Item "riegl.device_output_limits" updated (schema, #3811)
 * \version 2021-03-03/AW: Item "riegl.exponential_decomposition" updated (schema, #3822)
 * \version 2021-03-03/AW: Item "riegl.waveform_averaging_settings" added (#3821)
 * \version 2021-04-01/AW: Item "riegl.voxel_info" updated (schema, #3854)
 * \version 2021-04-16/AW: Item "riegl.voxel_info" updated (schema, #3866)
 * \version 2021-09-30/AW: Item "riegl.waveform_info" updated (schema+example, #4016)
 * \version 2021-10-04/AW: Improved spelling of the descriptions of some items
 * \version 2021-11-04/AW: Rename "riegl.record_names" to "riegl.item_names" (#4034)
 * \version 2022-03-11/AW: Item "riegl.devices" added (#4162)
 * \version 2022-03-14/AW: Item "riegl.stored_filters" added (#4164)
 * \version 2022-09-20/AW: Fix typos in schema of "riegl.georeferencing_parameters"
 * \version 2022-09-30/AW: Item "riegl.system_description" added (#4368)
 * \version 2022-10-10/AW: Correction of typos in the titles of some entries
 * \version 2022-10-20/AW: Item "riegl.stored_filters" updated (example, #4164)
 * \version 2023-01-19/AW: Item "riegl.ttip_configuration" added (#4449)
 * \version 2024-09-26/AW: Item "riegl.dyntrig" added (#5310)
 *
 *******************************************************************************
 */

#ifndef RDB_81EBCB65_FE94_471E_8D25_2B4D71CC91B1
#define RDB_81EBCB65_FE94_471E_8D25_2B4D71CC91B1

// Meta data item definition version
const char* const RDB_META_DATA_ITEMS_VERSION = "1.1.54";
const char* const RDB_META_DATA_ITEMS_DATE = "2023-01-19";

// Meta data item states
const unsigned char RDB_STATUS_REQUIRED = 1; // mandatory item
const unsigned char RDB_STATUS_OPTIONAL = 2; // optional item

// Container record for meta data item details
typedef struct MetaDataItemInfo
{
    const char*   name;
    const char*   title;
    const char*   description;
    unsigned char status;
    const char*   schema;
    const char*   example;
} MetaDataItemInfo;

// Angular notch filter parameters for window glass echoes
const MetaDataItemInfo RDB_RIEGL_ANGULAR_NOTCH_FILTER = {
    /* name        */ "riegl.angular_notch_filter",
    /* title       */ "Angular Notch Filter",
    /* description */ "Angular notch filter parameters for window glass echoes",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"angle\",\"range_mean\",\"amplitude_mean\"],\"title\":\"Angular "
    "Notch Filter\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"des"
    "cription\":\"Angular notch filter parameters for window glass echoes\",\"t"
    "ype\":\"object\",\"properties\":{\"range_mean\":{\"items\":{\"type\":\"number\"},\"d"
    "escription\":\"Mean range [m]\",\"type\":\"array\"},\"angle\":{\"items\":{\"type\":"
    "\"number\"},\"description\":\"Angle [deg]\",\"type\":\"array\"},\"amplitude_mean\""
    ":{\"items\":{\"type\":\"number\"},\"description\":\"Mean amplitude "
    "[dB]\",\"type\":\"array\"}}}"
    ,
    /* example: */
    "{\"range_mean\":[0.094,0.094,0.09075,0.08675,0.0815,0.0775,0.074,0.071,0"
    ".068,0.0675,0.06475],\"angle\":[14.0,15.0,16.0,17.0,18.0,19.0,20.0,21.0,"
    "22.0,23.0,24.0],\"amplitude_mean\":[3.780913,3.780913,3.480913,3.120913,"
    "2.850913,2.720913,2.680913,2.610913,2.530913,2.570913,2.570913]}"
};

// Atmospheric parameters
const MetaDataItemInfo RDB_RIEGL_ATMOSPHERE = {
    /* name        */ "riegl.atmosphere",
    /* title       */ "Atmosphere",
    /* description */ "Atmospheric parameters",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"temperature\",\"pressure\",\"rel_humidity\",\"pressure_sl\",\"am"
    "sl\",\"group_velocity\",\"attenuation\",\"wavelength\"],\"title\":\"Atmospheric "
    "Parameters\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"descr"
    "iption\":\"Atmospheric parameters\",\"type\":\"object\",\"properties\":{\"rel_hu"
    "midity\":{\"description\":\"Relative humidity along measurement path "
    "[%]\",\"type\":\"number\"},\"amsl\":{\"description\":\"Height above mean sea "
    "level (AMSL) [m]\",\"type\":\"number\"},\"wavelength\":{\"description\":\"Laser "
    "wavelength "
    "[nm]\",\"type\":\"number\"},\"pressure_sl\":{\"description\":\"Atmospheric "
    "pressure at sea level "
    "[mbar]\",\"type\":\"number\"},\"group_velocity\":{\"description\":\"Group "
    "velocity of laser beam "
    "[m/s]\",\"type\":\"number\"},\"attenuation\":{\"description\":\"Atmospheric "
    "attenuation "
    "[1/km]\",\"type\":\"number\"},\"temperature\":{\"description\":\"Temperature "
    "along measurement path "
    "[\\u00b0C]\",\"type\":\"number\"},\"pressure\":{\"description\":\"Pressure along "
    "measurment path [mbar]\",\"type\":\"number\"}}}"
    ,
    /* example: */
    "{\"rel_humidity\":63,\"amsl\":0,\"wavelength\":1550,\"pressure_sl\":970,\"group"
    "_velocity\":299711000.0,\"attenuation\":0.028125,\"temperature\":7,\"pressur"
    "e\":970}"
};

// Laser beam geometry details
const MetaDataItemInfo RDB_RIEGL_BEAM_GEOMETRY = {
    /* name        */ "riegl.beam_geometry",
    /* title       */ "Beam Geometry",
    /* description */ "Laser beam geometry details",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"beam_exit_diameter\",\"beam_divergence\"],\"title\":\"Beam Geo"
    "metry\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"descriptio"
    "n\":\"Laser beam geometry details\",\"type\":\"object\",\"properties\":{\"beam_d"
    "ivergence\":{\"description\":\"Beam divergence in far field [rad]\",\"type\":"
    "\"number\",\"minimum\":0,\"exclusiveMinimum\":false},\"beam_exit_diameter\":{\""
    "description\":\"Beam width at exit aperture "
    "[m]\",\"type\":\"number\",\"minimum\":0,\"exclusiveMinimum\":false}}}"
    ,
    /* example: */
    "{\"beam_divergence\":0.0003,\"beam_exit_diameter\":0.0072}"
};

// List of control object type definitions
const MetaDataItemInfo RDB_RIEGL_CONTROL_OBJECT_CATALOG = {
    /* name        */ "riegl.control_object_catalog",
    /* title       */ "Control Object Catalog",
    /* description */ "List of control object type definitions",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"types\"],\"title\":\"Control Object Catalog\",\"$schema\":\"http"
    "://json-schema.org/draft-04/schema#\",\"description\":\"List of control "
    "object type definitions\",\"type\":\"object\",\"properties\":{\"types\":{\"items"
    "\":{\"type\":\"object\",\"oneOf\":[{\"$ref\":\"#/definitions/rectangle\"},{\"$ref\""
    ":\"#/definitions/checkerboard2x2\"},{\"$ref\":\"#/definitions/chevron\"},{\"$"
    "ref\":\"#/definitions/circular_disk\"},{\"$ref\":\"#/definitions/cylinder\"},"
    "{\"$ref\":\"#/definitions/sphere\"},{\"$ref\":\"#/definitions/round_corner_cu"
    "be_prism\"}]},\"uniqueItems\":true,\"type\":\"array\"}},\"definitions\":{\"chevr"
    "on\":{\"description\":\"chevron\",\"allOf\":[{\"$ref\":\"#/definitions/common\"},"
    "{\"required\":[\"shape\",\"outside_edge_length\",\"thickness\"],\"description\":"
    "\"chevron specific properties\",\"type\":\"object\",\"properties\":{\"shape\":{\""
    "description\":\"shape identifier\",\"type\":\"string\",\"enum\":[\"chevron\"]},\"o"
    "utside_edge_length\":{\"description\":\"length of the two outer edges in m"
    "eters\",\"type\":\"number\",\"minimum\":0,\"exclusiveMinimum\":true},\"thickness"
    "\":{\"description\":\"thickness in meters\",\"type\":\"number\",\"minimum\":0,\"ex"
    "clusiveMinimum\":true}}}],\"type\":\"object\"},\"cylinder\":{\"description\":\"c"
    "ylinder\",\"allOf\":[{\"$ref\":\"#/definitions/common\"},{\"required\":[\"shape\""
    ",\"diameter\",\"height\"],\"description\":\"cylinder specific properties\",\"ty"
    "pe\":\"object\",\"properties\":{\"shape\":{\"description\":\"shape identifier\",\""
    "type\":\"string\",\"enum\":[\"cylinder\"]},\"diameter\":{\"description\":\"diamete"
    "r in meters\",\"type\":\"number\",\"minimum\":0,\"exclusiveMinimum\":true},\"hei"
    "ght\":{\"description\":\"height in meters\",\"type\":\"number\",\"minimum\":0,\"ex"
    "clusiveMinimum\":true}}}],\"type\":\"object\"},\"circular_disk\":{\"descriptio"
    "n\":\"circular disk\",\"allOf\":[{\"$ref\":\"#/definitions/common\"},{\"required"
    "\":[\"shape\",\"diameter\"],\"description\":\"circular disk specific propertie"
    "s\",\"type\":\"object\",\"properties\":{\"shape\":{\"description\":\"shape identif"
    "ier\",\"type\":\"string\",\"enum\":[\"circular_disk\"]},\"diameter\":{\"descriptio"
    "n\":\"diameter in meters\",\"type\":\"number\",\"minimum\":0,\"exclusiveMinimum\""
    ":true},\"offset\":{\"description\":\"offset in meters, e.g. reflector "
    "constant (optional)\",\"type\":\"number\"}}}],\"type\":\"object\"},\"rectangle\":"
    "{\"description\":\"rectangle\",\"allOf\":[{\"$ref\":\"#/definitions/common\"},{\""
    "required\":[\"shape\",\"length\",\"width\"],\"description\":\"rectangle specific"
    " properties\",\"type\":\"object\",\"properties\":{\"shape\":{\"type\":\"string\",\"e"
    "num\":[\"rectangle\"]},\"length\":{\"description\":\"length in meters\",\"type\":"
    "\"number\",\"minimum\":0,\"exclusiveMinimum\":true},\"width\":{\"description\":\""
    "width in meters\",\"type\":\"number\",\"minimum\":0,\"exclusiveMinimum\":true}}"
    "}],\"type\":\"object\"},\"round_corner_cube_prism\":{\"description\":\"round "
    "corner cube prism\",\"allOf\":[{\"$ref\":\"#/definitions/common\"},{\"required"
    "\":[\"shape\",\"diameter\"],\"description\":\"round corner cube prism specific"
    " properties\",\"type\":\"object\",\"properties\":{\"shape\":{\"description\":\"sha"
    "pe identifier\",\"type\":\"string\",\"enum\":[\"round_corner_cube_prism\"]},\"di"
    "ameter\":{\"description\":\"diameter in meters\",\"type\":\"number\",\"minimum\":"
    "0,\"exclusiveMinimum\":true},\"offset\":{\"description\":\"offset in meters, "
    "e.g. reflector constant (optional)\",\"type\":\"number\"}}}],\"type\":\"object"
    "\"},\"common\":{\"required\":[\"name\",\"shape\"],\"description\":\"common object "
    "properties\",\"type\":\"object\",\"properties\":{\"shape\":{\"description\":\"shap"
    "e identifier\",\"type\":\"string\",\"enum\":[\"rectangle\",\"checkerboard2x2\",\"c"
    "hevron\",\"circular_disk\",\"cylinder\",\"sphere\",\"round_corner_cube_prism\"]"
    "},\"description\":{\"description\":\"string describing the "
    "object\",\"type\":\"string\"},\"name\":{\"description\":\"unique type identifier"
    "\",\"type\":\"string\",\"minLength\":3},\"surface_type\":{\"description\":\"surfac"
    "e material type\",\"type\":\"string\",\"enum\":[\"retro_reflective_foil\",\"diff"
    "use\"]}}},\"checkerboard2x2\":{\"description\":\"checkerboard 2 by 2\",\"allOf"
    "\":[{\"$ref\":\"#/definitions/common\"},{\"required\":[\"shape\",\"square_length"
    "\"],\"description\":\"checkerboard specific properties\",\"type\":\"object\",\"p"
    "roperties\":{\"shape\":{\"description\":\"shape identifier\",\"type\":\"string\","
    "\"enum\":[\"checkerboard2x2\"]},\"square_length\":{\"description\":\"length of "
    "a square of the checkerboard in meters\",\"type\":\"number\",\"minimum\":0,\"e"
    "xclusiveMinimum\":true}}}],\"type\":\"object\"},\"sphere\":{\"description\":\"sp"
    "here\",\"allOf\":[{\"$ref\":\"#/definitions/common\"},{\"required\":[\"shape\",\"d"
    "iameter\"],\"description\":\"sphere specific properties\",\"type\":\"object\",\""
    "properties\":{\"shape\":{\"description\":\"shape identifier\",\"type\":\"string\""
    ",\"enum\":[\"sphere\"]},\"diameter\":{\"description\":\"diameter in meters\",\"ty"
    "pe\":\"number\",\"minimum\":0,\"exclusiveMinimum\":true}}}],\"type\":\"object\"}}"
    "}"
    ,
    /* example: */
    "{\"comments\":[\"This file contains a list of control object types (aka. "
    "'catalog').\",\"Each type is described by an object,\",\"which must "
    "contain at least the following parameters:\",\"  - name: unique "
    "identifier of the type\",\"  - shape: one of the following supported "
    "shapes:\",\"      - rectangle\",\"      - checkerboard2x2\",\"      - "
    "chevron\",\"      - circular_disk\",\"      - cylinder\",\"      - sphere\",\""
    "      - round_corner_cube_prism\",\"Depending on 'shape', the following "
    "parameters must/may be specified:\",\"  - rectangle:\",\"      - length: "
    "length in meters\",\"      - width: width in meters\",\"  - "
    "checkerboard2x2:\",\"      - square_length: length of a square of the "
    "checkerboard in meters\",\"  - circular_disk:\",\"      - diameter: "
    "diameter in meters\",\"      - offset: offset in meters, e.g. reflector "
    "constant (optional)\",\"  - chevron:\",\"      - outside_edge_length: "
    "length of the two outer edges in meters\",\"      - thickness: thickness"
    " in meters\",\"  - cylinder:\",\"      - diameter: diameter in meters\",\""
    "      - height: height in meters\",\"  - sphere:\",\"      - diameter: "
    "diameter in meters\",\"  - round_corner_cube_prism:\",\"      - diameter: "
    "diameter in meters\",\"      - offset: offset in meters, e.g. reflector "
    "constant (optional)\",\"Optional parameters:\",\"    - description: string"
    " describing the object\",\"    - surface_type: surface material type "
    "(either 'retro_reflective_foil' or "
    "'diffuse')\"],\"types\":[{\"shape\":\"rectangle\",\"description\":\"Rectangle "
    "(60cm x 30cm)\",\"length\":0.6,\"name\":\"Rectangle "
    "60x30\",\"width\":0.3},{\"shape\":\"rectangle\",\"description\":\"Rectangle "
    "(80cm x 40cm)\",\"length\":0.8,\"name\":\"Rectangle 80x40\",\"width\":0.4},{\"sh"
    "ape\":\"checkerboard2x2\",\"description\":\"Checkerboard (square length: "
    "30cm)\",\"name\":\"Checkerboard2x2 30\",\"square_length\":0.3},{\"shape\":\"chec"
    "kerboard2x2\",\"description\":\"Checkerboard (square length: "
    "50cm)\",\"name\":\"Checkerboard2x2 "
    "50\",\"square_length\":0.5},{\"shape\":\"chevron\",\"description\":\"Chevron "
    "(a=24''; b=4'')\",\"outside_edge_length\":0.6096,\"name\":\"Chevron "
    "24''/4''\",\"thickness\":0.1016},{\"shape\":\"circular_disk\",\"description\":\""
    " Circular Disk (diameter: 50cm)\",\"name\":\"Circular Disk 50\",\"surface_ty"
    "pe\":\"diffuse\",\"diameter\":0.5},{\"shape\":\"circular_disk\",\"surface_type\":"
    "\"retro_reflective_foil\",\"offset\":0.0,\"diameter\":0.05,\"description\":\"fl"
    "at circular reflector from retro-reflective foil\",\"name\":\"RIEGL flat "
    "reflector 50 mm\"},{\"shape\":\"circular_disk\",\"surface_type\":\"retro_refle"
    "ctive_foil\",\"offset\":0.0,\"diameter\":0.1,\"description\":\"flat circular "
    "reflector from retro-reflective foil\",\"name\":\"RIEGL flat reflector 100"
    " mm\"},{\"shape\":\"circular_disk\",\"surface_type\":\"retro_reflective_foil\","
    "\"offset\":0.0,\"diameter\":0.15,\"description\":\"flat circular reflector "
    "from retro-reflective foil\",\"name\":\"RIEGL flat reflector 150 mm\"},{\"sh"
    "ape\":\"cylinder\",\"surface_type\":\"retro_reflective_foil\",\"name\":\"RIEGL "
    "cylindrical reflector 50 "
    "mm\",\"diameter\":0.05,\"description\":\"cylindrical reflector from "
    "retro-reflective foil\",\"height\":0.05},{\"shape\":\"cylinder\",\"surface_typ"
    "e\":\"retro_reflective_foil\",\"name\":\"RIEGL cylindrical reflector 100 "
    "mm\",\"diameter\":0.1,\"description\":\"cylindrical reflector from "
    "retro-reflective "
    "foil\",\"height\":0.1},{\"shape\":\"sphere\",\"description\":\"Sphere (diameter:"
    " 200 mm)\",\"name\":\"Sphere 200 mm\",\"diameter\":0.2},{\"shape\":\"round_corne"
    "r_cube_prism\",\"description\":\"round corner cube "
    "prism\",\"offset\":0.0,\"name\":\"Corner Cube Prism 50 "
    "mm\",\"diameter\":0.05}]}"
};

// Details about the control object reference file
const MetaDataItemInfo RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE = {
    /* name        */ "riegl.control_object_reference_file",
    /* title       */ "Control Object Reference file",
    /* description */ "Details about the control object reference file",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Details about the control object reference file\",\"$sch"
    "ema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"object\",\"proper"
    "ties\":{\"reference_file\":{\"required\":[\"file_uuid\",\"file_path\"],\"descrip"
    "tion\":\"Reference to a control object "
    "file\",\"type\":\"object\",\"properties\":{\"file_path\":{\"description\":\"Path "
    "of the control object file relative to referring "
    "file\",\"type\":\"string\"},\"file_uuid\":{\"description\":\"Control object "
    "file's Universally Unique Identifier (RFC "
    "4122)\",\"type\":\"string\"}}}},\"title\":\"Control Object Reference file\"}"
    ,
    /* example: */
    "{\"reference_file\":{\"file_path\":\"../../../10_CONTROL_OBJECTS/ControlPoi"
    "nts.cpx\",\"file_uuid\":\"810f5d57-eccf-49ed-b07a-0cdd109b4213\"}}"
};

// Detection probability as a function of amplitude
const MetaDataItemInfo RDB_RIEGL_DETECTION_PROBABILITY = {
    /* name        */ "riegl.detection_probability",
    /* title       */ "Detection Probability",
    /* description */ "Detection probability as a function of amplitude",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"amplitude\",\"detection_probability\"],\"title\":\"Detection P"
    "robability\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"descr"
    "iption\":\"Detection probability as a function of amplitude\",\"type\":\"obj"
    "ect\",\"properties\":{\"detection_probability\":{\"items\":{\"type\":\"number\"},"
    "\"description\":\"Detection probability [0..1]\",\"type\":\"array\"},\"amplitud"
    "e\":{\"items\":{\"type\":\"number\"},\"description\":\"Amplitude "
    "[dB]\",\"type\":\"array\"}}}"
    ,
    /* example: */
    "{\"detection_probability\":[0.0,0.5,0.8,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0]"
    ",\"amplitude\":[0.0,1.0,2.0,3.0,4.0,5.0,6.0,7.0,8.0,9.0,10.0]}"
};

// Details about the device used to acquire the point cloud
const MetaDataItemInfo RDB_RIEGL_DEVICE = {
    /* name        */ "riegl.device",
    /* title       */ "Device Information",
    /* description */ "Details about the device used to acquire the point cloud",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"device_type\",\"serial_number\"],\"title\":\"Device Informatio"
    "n\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"description\":\""
    "Details about the device used to acquire the point cloud\",\"type\":\"obje"
    "ct\",\"properties\":{\"channel_number\":{\"description\":\"Laser channel "
    "number (not defined or 0: single channel device)\",\"type\":\"integer\",\"mi"
    "nimum\":0,\"exclusiveMinimum\":false},\"channel_text\":{\"description\":\"Opti"
    "onal channel description (e.g. 'Green Channel' for multi-channel "
    "devices)\",\"type\":\"string\"},\"serial_number\":{\"description\":\"Device "
    "serial number (e.g. "
    "S2221234)\",\"type\":\"string\"},\"device_type\":{\"description\":\"Device type "
    "identifier (e.g. "
    "VZ-400i)\",\"type\":\"string\"},\"device_name\":{\"description\":\"Optional "
    "device name (e.g. 'Scanner 1' for multi-scanner "
    "systems)\",\"type\":\"string\"},\"device_build\":{\"description\":\"Device build"
    " variant\",\"type\":\"string\"}}}"
    ,
    /* example: */
    "{\"channel_number\":0,\"channel_text\":\"\",\"serial_number\":\"S2221234\",\"devi"
    "ce_type\":\"VZ-400i\",\"device_name\":\"Scanner 1\",\"device_build\":\"\"}"
};

// Scanner device geometry details
const MetaDataItemInfo RDB_RIEGL_DEVICE_GEOMETRY = {
    /* name        */ "riegl.device_geometry",
    /* title       */ "Device Geometry",
    /* description */ "Scanner device geometry details",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"primary\"],\"title\":\"Device Geometry\",\"$schema\":\"http://js"
    "on-schema.org/draft-04/schema#\",\"description\":\"Scanner device geometry"
    " details\",\"type\":\"object\",\"properties\":{\"secondary\":{\"required\":[\"ID\","
    "\"content\"],\"description\":\"Additional device geometry structure (option"
    "al)\",\"type\":\"object\",\"properties\":{\"content\":{\"items\":{\"type\":\"number\""
    "},\"description\":\"Internal calibration values\",\"type\":\"array\"},\"ID\":{\"i"
    "tems\":{\"type\":\"integer\"},\"description\":\"Structure identifier\",\"minItem"
    "s\":2,\"type\":\"array\",\"maxItems\":2}}},\"primary\":{\"required\":[\"ID\",\"conte"
    "nt\"],\"description\":\"Primary device geometry structure (mandatory)\",\"ty"
    "pe\":\"object\",\"properties\":{\"content\":{\"items\":{\"type\":\"number\"},\"descr"
    "iption\":\"Internal calibration values\",\"type\":\"array\"},\"ID\":{\"items\":{\""
    "type\":\"integer\"},\"description\":\"Structure identifier\",\"minItems\":2,\"ty"
    "pe\":\"array\",\"maxItems\":2}}},\"amu\":{\"description\":\"Angle Measurement "
    "Unit\",\"type\":\"object\",\"properties\":{\"lineCC\":{\"description\":\"Line "
    "Circle Count (number of LSBs per full rotation about line axis)\",\"type"
    "\":\"number\",\"minimum\":0,\"exclusiveMinimum\":false},\"frameCC\":{\"descripti"
    "on\":\"Frame Circle Count (number of LSBs per full rotation about frame "
    "axis)\",\"type\":\"number\",\"minimum\":0,\"exclusiveMinimum\":false}}}}}"
    ,
    /* example: */
    "{\"secondary\":{\"content\":[0],\"ID\":[91,0]},\"primary\":{\"content\":[0],\"ID\""
    ":[4,0]},\"amu\":{\"lineCC\":124000,\"frameCC\":124000}}"
};

// Scanner passive channel device geometry details
const MetaDataItemInfo RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL = {
    /* name        */ "riegl.device_geometry_passive_channel",
    /* title       */ "Device Geometry Passive Channel",
    /* description */ "Scanner passive channel device geometry details",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"primary\"],\"title\":\"Device Geometry Passive Channel\",\"$sc"
    "hema\":\"http://json-schema.org/draft-04/schema#\",\"description\":\"Scanner"
    " passive channel device geometry details\",\"type\":\"object\",\"properties\""
    ":{\"primary\":{\"required\":[\"ID\",\"content\"],\"description\":\"Primary device"
    " geometry structure (mandatory)\",\"type\":\"object\",\"properties\":{\"conten"
    "t\":{\"items\":{\"type\":\"number\"},\"description\":\"Internal calibration valu"
    "es\",\"type\":\"array\"},\"ID\":{\"items\":{\"type\":\"integer\"},\"description\":\"St"
    "ructure identifier\",\"minItems\":2,\"type\":\"array\",\"maxItems\":2}}}}}"
    ,
    /* example: */
    "{\"primary\":{\"content\":[0],\"ID\":[143,0]}}"
};

// Limits of the measured values output by the device
const MetaDataItemInfo RDB_RIEGL_DEVICE_OUTPUT_LIMITS = {
    /* name        */ "riegl.device_output_limits",
    /* title       */ "Device Output Limits",
    /* description */ "Limits of the measured values output by the device",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Limits of the measured values output by the device. "
    "The limits depend on the device type, measurement program and/or scan "
    "pattern.\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\""
    "object\",\"properties\":{\"mta_zone_count_maximum\":{\"description\":\"Maximum"
    " number of MTA "
    "zones.\",\"type\":\"number\"},\"range_minimum\":{\"description\":\"Minimum "
    "possible range in "
    "meters.\",\"type\":\"number\"},\"amplitude_minimum\":{\"description\":\"Minimum "
    "possible amplitude in "
    "dB.\",\"type\":\"number\"},\"deviation_minimum\":{\"description\":\"Minimum "
    "possible pulse shape deviation.\",\"type\":\"number\"},\"echo_count_maximum\""
    ":{\"description\":\"Maximum number of echoes a laser shot can "
    "have.\",\"type\":\"number\"},\"reflectance_maximum\":{\"description\":\"Maximum "
    "possible reflectance in "
    "dB.\",\"type\":\"number\"},\"deviation_maximum\":{\"description\":\"Maximum "
    "possible pulse shape "
    "deviation.\",\"type\":\"number\"},\"range_maximum\":{\"description\":\"Maximum "
    "possible range in meters.\",\"type\":\"number\"},\"reflectance_minimum\":{\"de"
    "scription\":\"Minimum possible reflectance in dB.\",\"type\":\"number\"},\"bac"
    "kground_radiation_maximum\":{\"description\":\"Maximum possible background"
    " radiation.\",\"type\":\"number\"},\"amplitude_maximum\":{\"description\":\"Maxi"
    "mum possible amplitude in dB.\",\"type\":\"number\"},\"background_radiation_"
    "minimum\":{\"description\":\"Minimum possible background "
    "radiation.\",\"type\":\"number\"}},\"title\":\"Device Output Limits\"}"
    ,
    /* example: */
    "{\"mta_zone_count_maximum\":7,\"background_radiation_minimum\":0,\"reflecta"
    "nce_maximum\":100.0,\"amplitude_minimum\":0.0,\"range_maximum\":10000.0,\"re"
    "flectance_minimum\":-100.0,\"background_radiation_maximum\":0,\"range_mini"
    "mum\":2.9,\"deviation_minimum\":-1,\"amplitude_maximum\":100.0,\"deviation_m"
    "aximum\":32767}"
};

// Details about the devices used to acquire the point cloud
const MetaDataItemInfo RDB_RIEGL_DEVICES = {
    /* name        */ "riegl.devices",
    /* title       */ "Devices Information",
    /* description */ "Details about the devices used to acquire the point cloud",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Details about the devices used to acquire the point "
    "cloud (e.g. when merging point clouds of different devices)\",\"$schema\""
    ":\"http://json-schema.org/draft-04/schema#\",\"items\":{\"required\":[\"devic"
    "e_type\",\"serial_number\"],\"type\":\"object\",\"properties\":{\"channel_number"
    "\":{\"description\":\"Laser channel number (not defined or 0: single "
    "channel device)\",\"type\":\"integer\",\"minimum\":0,\"exclusiveMinimum\":false"
    "},\"channel_text\":{\"description\":\"Optional channel description (e.g. "
    "'Green Channel' for multi-channel "
    "devices)\",\"type\":\"string\"},\"serial_number\":{\"description\":\"Device "
    "serial number (e.g. "
    "S2221234)\",\"type\":\"string\"},\"device_type\":{\"description\":\"Device type "
    "identifier (e.g. "
    "VZ-400i)\",\"type\":\"string\"},\"signed\":{\"description\":\"Flag that is set "
    "when the original 'riegl.device' entry in the source file was "
    "correctly "
    "signed.\",\"type\":\"boolean\"},\"device_name\":{\"description\":\"Optional "
    "device name (e.g. 'Scanner 1' for multi-scanner "
    "systems)\",\"type\":\"string\"},\"device_build\":{\"description\":\"Device build"
    " variant\",\"type\":\"string\"}}},\"type\":\"array\",\"title\":\"Devices "
    "Information\"}"
    ,
    /* example: */
    "[{\"channel_number\":0,\"channel_text\":\"\",\"serial_number\":\"S2221234\",\"dev"
    "ice_type\":\"VZ-400i\",\"signed\":false,\"device_name\":\"Scanner 1\",\"device_b"
    "uild\":\"\"},{\"channel_number\":1,\"channel_text\":\"\",\"serial_number\":\"S2222"
    "680\",\"device_type\":\"VQ-1560i-DW\",\"signed\":true,\"device_name\":\"Scanner "
    "2\",\"device_build\":\"\"},{\"channel_number\":2,\"channel_text\":\"\",\"serial_nu"
    "mber\":\"S2222680\",\"device_type\":\"VQ-1560i-DW\",\"signed\":true,\"device_nam"
    "e\":\"Scanner 3\",\"device_build\":\"\"}]"
};

// Dyntrig
const MetaDataItemInfo RDB_RIEGL_DYNTRIG = {
    /* name        */ "riegl.dyntrig",
    /* title       */ "Dyntrig",
    /* description */ "Dyntrig",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Dyntrig\",\"$schema\":\"http://json-schema.org/draft-04/sc"
    "hema#\",\"properties\":{\"pre\":{\"required\":[\"nc\",\"a\"],\"description\":\"Dyntr"
    "ig pre "
    "values\",\"type\":\"object\",\"properties\":{\"nc\":{\"description\":\"Number of e"
    "ntries\",\"type\":\"integer\",\"maximum\":255,\"minimum\":0},\"a\":{\"items\":{\"typ"
    "e\":\"number\"},\"minItems\":1,\"type\":\"array\",\"maxItems\":2080,\"description\""
    ":\"...\"}}},\"post\":{\"required\":[\"nc\",\"a\"],\"description\":\"Dyntrig post "
    "values\",\"type\":\"object\",\"properties\":{\"nc\":{\"description\":\"Number of e"
    "ntries\",\"type\":\"integer\",\"maximum\":255,\"minimum\":0},\"a\":{\"items\":{\"typ"
    "e\":\"number\"},\"minItems\":1,\"type\":\"array\",\"maxItems\":2080,\"description\""
    ":\"...\"}}},\"offset\":{\"description\":\"Offset in units of dB, for "
    "calculation of line\",\"type\":\"number\"},\"tab\":{\"items\":{\"required\":[\"thr"
    "a1\",\"del1\",\"dec1\",\"thra2\",\"del2\",\"dec2\"],\"description\":\"...\",\"type\":\"o"
    "bject\",\"properties\":{\"thra2\":{\"description\":\"Pre-trigger threshold in "
    "units of dB\",\"type\":\"number\"},\"dec1\":{\"description\":\"Decay of "
    "post-trigger threshold after del1 in units of "
    "dB/m\",\"type\":\"number\"},\"thra1\":{\"description\":\"Post-trigger threshold "
    "in units of dB\",\"type\":\"number\"},\"dec2\":{\"description\":\"Rise of "
    "pre-trigger threshold after del2 in units of "
    "dB/m\",\"type\":\"number\"},\"del2\":{\"description\":\"Length of constant "
    "pre-trigger threshold elevation in units of "
    "m\",\"type\":\"number\"},\"del1\":{\"description\":\"Length of constant "
    "post-trigger threshold elevation in units of m\",\"type\":\"number\"}}},\"mi"
    "nItems\":1,\"type\":\"array\",\"maxItems\":128,\"description\":\"...\"},\"scale\":{"
    "\"description\":\"Scale in units of dB, for calculation of line: line "
    "number "
    "N=(amplitude-offset)/scale\",\"type\":\"number\"}},\"title\":\"Dyntrig\"}"
    ,
    /* example: */
    "{\"pre\":{\"nc\":128,\"a\":[78,86,126,134,31]},\"post\":{\"nc\":128,\"a\":[78,86,1"
    "26,134,31]},\"offset\":0.0,\"tab\":[{\"thra2\":0.0,\"dec1\":0.0,\"thra1\":0.0,\"d"
    "ec2\":0.0,\"del2\":0.0,\"del1\":0.0}],\"scale\":1.0}"
};

// Details about echo files
const MetaDataItemInfo RDB_RIEGL_ECHO_INFO = {
    /* name        */ "riegl.echo_info",
    /* title       */ "Echo Information",
    /* description */ "Details about echo files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"echo_file\"],\"title\":\"Echo Information\",\"$schema\":\"http:/"
    "/json-schema.org/draft-04/schema#\",\"description\":\"Details about echo f"
    "iles\",\"type\":\"object\",\"properties\":{\"echo_file\":{\"required\":[\"file_ext"
    "ension\"],\"type\":\"object\",\"properties\":{\"file_uuid\":{\"description\":\"Fil"
    "e's Universally Unique Identifier (RFC "
    "4122)\",\"type\":\"string\"},\"file_extension\":{\"description\":\"Echo file "
    "extension, without the leading dot\",\"type\":\"string\"}}}}}"
    ,
    /* example: */
    "{\"echo_file\":{\"file_uuid\":\"26a03615-67c0-4bea-8fe8-c577378fe661\",\"file"
    "_extension\":\"owp\"}}"
};

// Details for exponential decomposition of full waveform data
const MetaDataItemInfo RDB_RIEGL_EXPONENTIAL_DECOMPOSITION = {
    /* name        */ "riegl.exponential_decomposition",
    /* title       */ "Exponential Decomposition",
    /* description */ "Details for exponential decomposition of full waveform data",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Exponential Decomposition\",\"$schema\":\"http://json-schema.org"
    "/draft-04/schema#\",\"patternProperties\":{\"^[0-9]+$\":{\"description\":\"one"
    " field per channel, field name is channel "
    "index\",\"$ref\":\"#/definitions/channel\"}},\"description\":\"Details for "
    "exponential decomposition of full waveform data\",\"additionalProperties"
    "\":false,\"type\":\"object\",\"definitions\":{\"channel\":{\"required\":[\"delay\","
    "\"scale\",\"parameter\"],\"type\":\"object\",\"properties\":{\"delay\":{\"descripti"
    "on\":\"delay calibration in seconds\",\"type\":\"number\"},\"parameter\":{\"requ"
    "ired\":[\"A\",\"B\",\"gamma\",\"omega\"],\"description\":\"parameters of the "
    "syswave exponential sum\",\"type\":\"object\",\"properties\":{\"gamma\":{\"items"
    "\":{\"type\":\"number\"},\"description\":\"decay in 1/second\",\"type\":\"array\"},"
    "\"A\":{\"items\":{\"type\":\"number\"},\"description\":\"real part of amplitude "
    "factor in units of full-scale\",\"type\":\"array\"},\"omega\":{\"items\":{\"type"
    "\":\"number\"},\"description\":\"angular frequency in Hz\",\"type\":\"array\"},\"B"
    "\":{\"items\":{\"type\":\"number\"},\"description\":\"imaginary part of "
    "amplitude factor in units of full-scale\",\"type\":\"array\"}}},\"a_lin\":{\"e"
    "xclusiveMaximum\":false,\"minimum\":0,\"exclusiveMinimum\":false,\"descripti"
    "on\":\"relative linear amplitude range "
    "[0..1]\",\"type\":\"number\",\"maximum\":1},\"scale\":{\"description\":\"amplitude"
    " calibration\",\"type\":\"number\"}}}}}"
    ,
    /* example: */
    "{\"0\":{\"delay\":3.783458418887631e-09,\"parameter\":{\"gamma\":[-1094726528."
    "0,-769562752.0,-848000064.0],\"A\":[0.9772450923919678,0.335433512926101"
    "7,-1.312678575515747],\"omega\":[352020896.0,3647927552.0,-1977987072.0]"
    ",\"B\":[-3.9813032150268555,0.08622030913829803,-0.3152860999107361]},\"a"
    "_lin\":0.27,\"scale\":1.0},\"1\":{\"delay\":3.5e-09,\"parameter\":{\"gamma\":[-10"
    "94726528.0,-769562752.0,-848000064.0],\"A\":[0.9,0.3,-1.3],\"omega\":[3520"
    "20896.0,3647927552.0,-1977987072.0],\"B\":[-3.9,0.0,-0.3]},\"a_lin\":0.9,\""
    "scale\":1.0}}"
};

// Details for Gaussian decomposition of full waveform data
const MetaDataItemInfo RDB_RIEGL_GAUSSIAN_DECOMPOSITION = {
    /* name        */ "riegl.gaussian_decomposition",
    /* title       */ "Gaussian Decomposition",
    /* description */ "Details for Gaussian decomposition of full waveform data",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"amplitude_lsb_low_power\",\"amplitude_lsb_high_power\",\"amp"
    "litude_db\",\"range_offset_sec_low_power\",\"range_offset_sec_high_power\"]"
    ",\"title\":\"Gaussian Decomposition\",\"$schema\":\"http://json-schema.org/dr"
    "aft-04/schema#\",\"description\":\"riegl.gaussian_decomposition contains "
    "information relevant for extracting calibrated amplitudes and "
    "calibrated ranges from a Gaussian decomposition of full waveform data."
    " This information is contained in a table with five columns. Two "
    "columns are to be used as input: amplitude_lsb_low_power and "
    "amplitude_lsb_high_power. The other three columns provide the outputs."
    " Amplitude_db gives the calibrated amplitude in the optical regime in "
    "decibels. The range offset columns provide additive range offsets, "
    "given in units of seconds, for each channel.\",\"type\":\"object\",\"propert"
    "ies\":{\"amplitude_lsb_high_power\":{\"items\":{\"type\":\"number\"},\"type\":\"ar"
    "ray\"},\"amplitude_lsb_low_power\":{\"items\":{\"type\":\"number\"},\"type\":\"arr"
    "ay\"},\"range_offset_sec_low_power\":{\"items\":{\"type\":\"number\"},\"type\":\"a"
    "rray\"},\"range_offset_sec_high_power\":{\"items\":{\"type\":\"number\"},\"type\""
    ":\"array\"},\"amplitude_db\":{\"items\":{\"type\":\"number\"},\"type\":\"array\"}}}"
    ,
    /* example: */
    "{\"amplitude_lsb_high_power\":[],\"amplitude_lsb_low_power\":[],\"range_off"
    "set_sec_low_power\":[],\"range_offset_sec_high_power\":[],\"amplitude_db\":"
    "[]}"
};

// Point cloud georeferencing information
const MetaDataItemInfo RDB_RIEGL_GEO_TAG = {
    /* name        */ "riegl.geo_tag",
    /* title       */ "Geo Tag",
    /* description */ "Point cloud georeferencing information",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Point cloud georeferencing information\",\"$schema\":\"htt"
    "p://json-schema.org/draft-04/schema#\",\"type\":\"object\",\"properties\":{\"c"
    "rs\":{\"description\":\"Global Coordinate Reference System. Please note "
    "that only 3D Cartesian Coordinate Systems are allowed.\",\"type\":\"object"
    "\",\"properties\":{\"wkt\":{\"description\":\"\\\"Well-Known Text\\\" string, OGC "
    "WKT dialect (see http://www.opengeospatial.org/standards/wkt-crs)\",\"ty"
    "pe\":\"string\"},\"name\":{\"description\":\"Coordinate reference system "
    "name\",\"type\":\"string\"},\"epsg\":{\"description\":\"EPSG code\",\"type\":\"integ"
    "er\",\"minimum\":0}}},\"pose\":{\"items\":{\"items\":{\"description\":\"columns\",\""
    "type\":\"number\"},\"description\":\"rows\",\"minItems\":4,\"type\":\"array\",\"maxI"
    "tems\":4},\"description\":\"Coordinate Transformation Matrix to transform "
    "from File Coordinate System to Global Coordinate Reference System. 4x4"
    " matrix stored as two dimensional array, row major "
    "order.\",\"minItems\":4,\"type\":\"array\",\"maxItems\":4}},\"title\":\"Geo Tag\"}"
    ,
    /* example: */
    "{\"crs\":{\"wkt\":\"GEOCCS[\\\"WGS84 Geocentric\\\",DATUM[\\\"WGS84\\\",SPHEROID[\\\""
    "WGS84\\\",6378137.000,298.257223563,AUTHORITY[\\\"EPSG\\\",\\\"7030\\\"]],AUTHOR"
    "ITY[\\\"EPSG\\\",\\\"6326\\\"]],PRIMEM[\\\"Greenwich\\\",0.0000000000000000,AUTHOR"
    "ITY[\\\"EPSG\\\",\\\"8901\\\"]],UNIT[\\\"Meter\\\",1.00000000000000000000,AUTHORIT"
    "Y[\\\"EPSG\\\",\\\"9001\\\"]],AXIS[\\\"X\\\",OTHER],AXIS[\\\"Y\\\",EAST],AXIS[\\\"Z\\\",NO"
    "RTH],AUTHORITY[\\\"EPSG\\\",\\\"4978\\\"]]\",\"name\":\"WGS84 Geocentric\",\"epsg\":4"
    "978},\"pose\":[[-0.269827776749716,-0.723017716139738,0.635954678449952,"
    "4063882.500831],[0.962908599449764,-0.20260517250352,0.178208229833847"
    ",1138787.607461],[0.0,0.660451759194338,0.7508684796801,4766084.550196"
    "],[0.0,0.0,0.0,1.0]]}"
};

// Geometric scale factor applied to point coordinates
const MetaDataItemInfo RDB_RIEGL_GEOMETRIC_SCALE_FACTOR = {
    /* name        */ "riegl.geometric_scale_factor",
    /* title       */ "Geometric Scale Factor",
    /* description */ "Geometric scale factor applied to point coordinates",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"number\",\""
    "exclusiveMinimum\":true,\"minimum\":0,\"description\":\"Geometric scale "
    "factor applied to point coordinates\"}"
    ,
    /* example: */
    "1.0"
};

// Parameters used for georeferencing of the point cloud
const MetaDataItemInfo RDB_RIEGL_GEOREFERENCING_PARAMETERS = {
    /* name        */ "riegl.georeferencing_parameters",
    /* title       */ "Georeferencing Parameters",
    /* description */ "Parameters used for georeferencing of the point cloud",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Parameters used for georeferencing of the point cloud\""
    ",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"object\",\""
    "properties\":{\"socs_to_rocs_matrix\":{\"items\":{\"items\":{\"description\":\"c"
    "olumns\",\"type\":\"number\"},\"description\":\"rows\",\"minItems\":4,\"type\":\"arr"
    "ay\",\"maxItems\":4},\"description\":\"Coordinate Transformation Matrix to "
    "transform from Scanner's Own Coordinate System to Record Coordinate "
    "System. 4x4 matrix stored as two dimensional array, row major order.\","
    "\"minItems\":4,\"type\":\"array\",\"maxItems\":4},\"socs_to_body_matrix\":{\"item"
    "s\":{\"items\":{\"description\":\"columns\",\"type\":\"number\"},\"description\":\"r"
    "ows\",\"minItems\":4,\"type\":\"array\",\"maxItems\":4},\"description\":\"Coordina"
    "te Transformation Matrix to transform from Scanner's Own Coordinate "
    "System to Body Coordinate System. 4x4 matrix stored as two dimensional"
    " array, row major order.\",\"minItems\":4,\"type\":\"array\",\"maxItems\":4},\"t"
    "rajectory_file\":{\"required\":[\"file_extension\"],\"description\":\"Trajecto"
    "ry data used for georeferencing of the point cloud\",\"type\":\"object\",\"p"
    "roperties\":{\"file_uuid\":{\"description\":\"File's Universally Unique "
    "Identifier (RFC "
    "4122)\",\"type\":\"string\"},\"file_extension\":{\"description\":\"Trajectory "
    "file extension, without the leading dot\",\"type\":\"string\"}}},\"body_coor"
    "dinate_system_type\":{\"description\":\"BODY coordinate frame (NED: "
    "North-East-Down, ENU: East-North-Up), default: NED\",\"type\":\"string\",\"e"
    "num\":[\"NED\",\"ENU\"]},\"trajectory_offsets\":{\"description\":\"Correction "
    "offsets applied to the trajectory data\",\"type\":\"object\",\"properties\":{"
    "\"offset_roll\":{\"description\":\"[deg]\",\"type\":\"number\"},\"offset_pitch\":{"
    "\"description\":\"[deg]\",\"type\":\"number\"},\"offset_north\":{\"description\":\""
    "[m]\",\"type\":\"number\"},\"offset_east\":{\"description\":\"[m]\",\"type\":\"numbe"
    "r\"},\"offset_height\":{\"description\":\"[m]\",\"type\":\"number\"},\"offset_time"
    "\":{\"description\":\"[s]\",\"type\":\"number\"},\"version\":{\"description\":\"Mean"
    "ing of offset values and how to apply them; version 0: "
    "Rz(yaw+offset_yaw)*Ry(pitch+offset_pitch)*Rx(roll+offset_roll), "
    "version 1: Rz(yaw)*Ry(pitch)*Rx(roll) * Rz(offset_yaw)*Ry(offset_pitch"
    ")*Rx(offset_roll)\",\"type\":\"integer\"},\"offset_yaw\":{\"description\":\"[deg"
    "]\",\"type\":\"number\"}}}},\"title\":\"Georeferencing Parameters\"}"
    ,
    /* example: */
    "{\"socs_to_body_matrix\":[[-0.269827776749716,-0.723017716139738,0.63595"
    "4678449952,0.0],[0.962908599449764,-0.20260517250352,0.178208229833847"
    ",0.0],[0.0,0.660451759194338,0.7508684796801,0.0],[0.0,0.0,0.0,1.0]],\""
    "trajectory_file\":{\"file_uuid\":\"93a03615-66c0-4bea-8ff8-c577378fe660\",\""
    "file_extension\":\"pofx\"},\"body_coordinate_system_type\":\"NED\",\"trajector"
    "y_offsets\":{\"offset_roll\":0.03,\"offset_pitch\":0.01,\"offset_north\":0.07"
    ",\"offset_east\":0.15,\"offset_height\":-0.2,\"offset_time\":18.007,\"version"
    "\":0,\"offset_yaw\":-0.45}}"
};

// Map of item names
const MetaDataItemInfo RDB_RIEGL_ITEM_NAMES = {
    /* name        */ "riegl.item_names",
    /* title       */ "Item Names",
    /* description */ "Map of item names",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"patternProperties\":{\"^-?[0-9]+$\":{\"description\":\"One field per item,"
    " field name is item id, field value is item name\",\"type\":\"string\"}},\"$"
    "schema\":\"http://json-schema.org/draft-04/schema#\",\"description\":\"Map "
    "of item "
    "names\",\"additionalProperties\":false,\"type\":\"object\",\"title\":\"Item "
    "Names\"}"
    ,
    /* example: */
    "{\"-1\":\"Name of item with id -1\",\"2\":\"Name of item with id 2\",\"1\":\"Name"
    " of item with id 1\",\"47\":\"Name of item with id 47\"}"
};

// License keys for software features
const MetaDataItemInfo RDB_RIEGL_LICENSES = {
    /* name        */ "riegl.licenses",
    /* title       */ "Software License Keys",
    /* description */ "License keys for software features",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"patternProperties\":{\"^.*$\":{\"items\":{\"description\":\"License key "
    "(example: '46AE032A - 39882AC4 - 9EC0A184 - "
    "6F163D73')\",\"type\":\"string\"},\"description\":\"Each field of the object "
    "represents a feature and holds a list of license keys, where the field"
    " name is the feature name.\",\"minItems\":1,\"type\":\"array\"}},\"$schema\":\"h"
    "ttp://json-schema.org/draft-04/schema#\",\"description\":\"License keys "
    "for software features\",\"additionalProperties\":false,\"type\":\"object\",\"t"
    "itle\":\"Software License Keys\"}"
    ,
    /* example: */
    "{\"Full Waveform Analysis Topography\":[\"0FD5FF07 - 011A1255 - 9F76CACA "
    "- 8D2ED557\"],\"Full Waveform Analysis Topography with GPU "
    "support\":[\"8AB44126 - 23B92250 - 16E2689F - 34EF7E7B\"],\"MTA "
    "resolution\":[\"468E020A - 39A922E4 - B681A184 - "
    "673E3D72\"],\"Georeferencing\":[\"46AE032A - 39882AC4 - 9EC0A184 - "
    "6F163D73\"]}"
};

// Parameters for MTA processing
const MetaDataItemInfo RDB_RIEGL_MTA_SETTINGS = {
    /* name        */ "riegl.mta_settings",
    /* title       */ "MTA Settings",
    /* description */ "Parameters for MTA processing",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Parameters for MTA processing\",\"$schema\":\"http://json-"
    "schema.org/draft-04/schema#\",\"type\":\"object\",\"properties\":{\"zone_count"
    "\":{\"description\":\"Maximum number of MTA zones.\",\"type\":\"integer\",\"maxi"
    "mum\":255,\"minimum\":0},\"zone_width\":{\"description\":\"Width of a MTA zone"
    " in meter.\",\"type\":\"number\",\"minimum\":0},\"modulation_depth\":{\"descript"
    "ion\":\"Depth of pulse position modulation in "
    "meter.\",\"type\":\"number\",\"minimum\":0}},\"title\":\"MTA Settings\"}"
    ,
    /* example: */
    "{\"zone_count\":23,\"zone_width\":149.896225,\"modulation_depth\":9.368514}"
};

// Lookup table for range correction based on raw range
const MetaDataItemInfo RDB_RIEGL_NEAR_RANGE_CORRECTION = {
    /* name        */ "riegl.near_range_correction",
    /* title       */ "Near Range Correction Table",
    /* description */ "Lookup table for range correction based on raw range",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"delta\",\"content\"],\"title\":\"Near Range Correction Table\","
    "\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"description\":\"Loo"
    "kup table for range correction based on raw "
    "range\",\"type\":\"object\",\"properties\":{\"delta\":{\"description\":\"Delta "
    "between table entries [m], first entry is at range = 0 m\",\"type\":\"numb"
    "er\"},\"content\":{\"items\":{\"type\":\"number\"},\"description\":\"Correction "
    "value [m] to be added to the raw "
    "range\",\"minItems\":1,\"type\":\"array\",\"maxItems\":2000}}}"
    ,
    /* example: */
    "{\"delta\":0.512,\"content\":[0.0]}"
};

// Standard deviation for range and amplitude as a function of amplitude
const MetaDataItemInfo RDB_RIEGL_NOISE_ESTIMATES = {
    /* name        */ "riegl.noise_estimates",
    /* title       */ "Noise Estimates",
    /* description */ "Standard deviation for range and amplitude as a function of amplitude",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"amplitude\",\"range_sigma\",\"amplitude_sigma\"],\"title\":\"Noi"
    "se Estimates\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"des"
    "cription\":\"Standard deviation for range and amplitude as a function of"
    " amplitude\",\"type\":\"object\",\"properties\":{\"range_sigma\":{\"items\":{\"typ"
    "e\":\"number\"},\"description\":\"Sigma range [m]\",\"type\":\"array\"},\"amplitud"
    "e\":{\"items\":{\"type\":\"number\"},\"description\":\"Amplitude [dB]\",\"type\":\"a"
    "rray\"},\"amplitude_sigma\":{\"items\":{\"type\":\"number\"},\"description\":\"Sig"
    "ma amplitude [dB]\",\"type\":\"array\"}}}"
    ,
    /* example: */
    "{\"range_sigma\":[0.065,0.056,0.046,0.038,0.032,0.027,0.024,0.021,0.018,"
    "0.016,0.014],\"amplitude\":[0.0,1.0,2.0,3.0,4.0,5.0,6.0,7.0,8.0,9.0,10.0"
    "],\"amplitude_sigma\":[0.988,0.988,0.875,0.774,0.686,0.608,0.54,0.482,0."
    "432,0.39,0.354]}"
};

// Notch filter parameters for window glass echoes
const MetaDataItemInfo RDB_RIEGL_NOTCH_FILTER = {
    /* name        */ "riegl.notch_filter",
    /* title       */ "Notch Filter",
    /* description */ "Notch filter parameters for window glass echoes",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"range_minimum\",\"range_maximum\",\"amplitude_maximum\"],\"tit"
    "le\":\"Notch Filter\",\"$schema\":\"http://json-schema.org/draft-04/schema#\""
    ",\"description\":\"Notch filter parameters for window glass echoes\",\"type"
    "\":\"object\",\"properties\":{\"range_minimum\":{\"description\":\"Minimum range"
    " [m]\",\"type\":\"number\"},\"range_maximum\":{\"description\":\"Maximum range "
    "[m]\",\"type\":\"number\"},\"amplitude_maximum\":{\"description\":\"Maximum "
    "amplitude [dB]\",\"type\":\"number\",\"minimum\":0}}}"
    ,
    /* example: */
    "{\"range_minimum\":-0.5,\"range_maximum\":0.2,\"amplitude_maximum\":18.0}"
};

// Details about the pixels contained in the file
const MetaDataItemInfo RDB_RIEGL_PIXEL_INFO = {
    /* name        */ "riegl.pixel_info",
    /* title       */ "Pixel Information",
    /* description */ "Details about the pixels contained in the file",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"size\"],\"title\":\"Pixel Information\",\"$schema\":\"http://jso"
    "n-schema.org/draft-04/schema#\",\"description\":\"Details about the pixels"
    " contained in the "
    "file\",\"type\":\"object\",\"properties\":{\"size_llcs\":{\"description\":\"Size "
    "of pixels in a locally levelled cartesian coordinate system (xy). This"
    " is only used for pixels based on a map projection.\",\"$ref\":\"#/definit"
    "ions/pixel_size\"},\"size\":{\"description\":\"Size of pixels in file "
    "coordinate system.\",\"$ref\":\"#/definitions/pixel_size\"}},\"definitions\":"
    "{\"pixel_size\":{\"items\":{\"description\":\"Length of pixel edge "
    "[m].\",\"type\":\"number\",\"minimum\":0},\"description\":\"Size of "
    "pixels.\",\"minItems\":2,\"type\":\"array\",\"maxItems\":2}}}"
    ,
    /* example: */
    "{\"size_llcs\":[0.5156575252891171,0.5130835356683303],\"size\":[0.5971642"
    "834779395,0.5971642834779395]}"
};

// Details about the plane patch matching process
const MetaDataItemInfo RDB_RIEGL_PLANE_PATCH_MATCHING = {
    /* name        */ "riegl.plane_patch_matching",
    /* title       */ "Plane Patch Matching",
    /* description */ "Details about the plane patch matching process",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"plane_patch_file_one\",\"plane_patch_file_two\"],\"title\":\"P"
    "lane Patch Matching\",\"$schema\":\"http://json-schema.org/draft-04/schema"
    "#\",\"description\":\"Details about the plane patch matching process\",\"typ"
    "e\":\"object\",\"properties\":{\"plane_patch_file_two\":{\"description\":\"Refer"
    "ence to the plane patch file two\",\"$ref\":\"#/definitions/file_reference"
    "\"},\"plane_patch_file_one\":{\"description\":\"Reference to the plane patch"
    " file one\",\"$ref\":\"#/definitions/file_reference\"}},\"definitions\":{\"fil"
    "e_reference\":{\"required\":[\"file_uuid\",\"file_path\"],\"description\":\"Refe"
    "rence to a plane patch "
    "file\",\"type\":\"object\",\"properties\":{\"file_path\":{\"description\":\"Path "
    "of the plane patch file relative to the match "
    "file\",\"type\":\"string\"},\"file_uuid\":{\"description\":\"Plane patch file's "
    "Universally Unique Identifier (RFC 4122)\",\"type\":\"string\"}}}}}"
    ,
    /* example: */
    "{\"plane_patch_file_two\":{\"file_path\":\"project.ptch\",\"file_uuid\":\"fa47d"
    "509-a64e-49ce-8b14-ff3130fbefa9\"},\"plane_patch_file_one\":{\"file_path\":"
    "\"Record009_Line001/191025_121410_Scanner_1.ptch\",\"file_uuid\":\"810f5d57"
    "-eccf-49ed-b07a-0cdd109b4213\"}}"
};

// Statistics about plane patches found by plane patch extractor
const MetaDataItemInfo RDB_RIEGL_PLANE_PATCH_STATISTICS = {
    /* name        */ "riegl.plane_patch_statistics",
    /* title       */ "Plane Patch Statistics",
    /* description */ "Statistics about plane patches found by plane patch extractor",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Statistics about plane patches found by plane patch ex"
    "tractor\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"o"
    "bject\",\"properties\":{\"total_horizontal_area\":{\"description\":\"sum of "
    "all plane patch areas projected to horizontal plane "
    "[m\\u00b2]\",\"type\":\"number\"},\"total_area\":{\"description\":\"sum of all "
    "plane patch areas [m\\u00b2]\",\"type\":\"number\"}},\"title\":\"Plane Patch "
    "Statistics\"}"
    ,
    /* example: */
    "{\"total_horizontal_area\":13954.601,\"total_area\":14007.965}"
};

// Settings and classes for plane slope classification
const MetaDataItemInfo RDB_RIEGL_PLANE_SLOPE_CLASS_INFO = {
    /* name        */ "riegl.plane_slope_class_info",
    /* title       */ "Plane Slope Class Info",
    /* description */ "Settings and classes for plane slope classification",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"settings\",\"classes\"],\"title\":\"Plane Slope Class Info\",\"$"
    "schema\":\"http://json-schema.org/draft-04/schema#\",\"description\":\"Setti"
    "ngs and classes for plane slope classification\",\"type\":\"object\",\"prope"
    "rties\":{\"classes\":{\"description\":\"Class definition table\",\"additionalP"
    "roperties\":false,\"type\":\"object\",\"patternProperties\":{\"^[0-9]+$\":{\"des"
    "cription\":\"one field per class, field name is class number, field "
    "value is class "
    "name\",\"type\":\"string\"}}},\"settings\":{\"description\":\"Classification "
    "settings, details see documentation of rdbplanes\",\"type\":\"object\",\"one"
    "Of\":[{\"$ref\":\"#/definitions/method-1\"},{\"$ref\":\"#/definitions/method-2"
    "\"}]}},\"definitions\":{\"method-1\":{\"required\":[\"plane_classification_met"
    "hod\",\"maximum_inclination_angle_horizontal\"],\"description\":\"Classifica"
    "tion method 1\",\"type\":\"object\",\"properties\":{\"plane_classification_met"
    "hod\":{\"description\":\"method ID (=1)\",\"type\":\"integer\",\"maximum\":1,\"min"
    "imum\":1},\"maximum_inclination_angle_horizontal\":{\"description\":\"maximu"
    "m inclination angle of horizontal plane patches [deg]\",\"type\":\"number\""
    ",\"maximum\":360.0,\"minimum\":-360.0}}},\"method-2\":{\"required\":[\"plane_cl"
    "assification_method\",\"sloping_plane_classes_minimum_angle\",\"sloping_pl"
    "ane_classes_maximum_angle\"],\"description\":\"Classification method 2\",\"t"
    "ype\":\"object\",\"properties\":{\"sloping_plane_classes_maximum_angle\":{\"de"
    "scription\":\"maximum inclination angle of sloping plane patches [deg]\","
    "\"type\":\"number\",\"maximum\":360.0,\"minimum\":-360.0},\"plane_classificatio"
    "n_method\":{\"description\":\"method ID (=2)\",\"type\":\"integer\",\"maximum\":2"
    ",\"minimum\":2},\"sloping_plane_classes_minimum_angle\":{\"description\":\"mi"
    "nimum inclination angle of sloping plane patches "
    "[deg]\",\"type\":\"number\",\"maximum\":360.0,\"minimum\":-360.0}}}}}"
    ,
    /* example: */
    "{\"classes\":{\"1\":\"horizontal, pointing up\",\"2\":\"sloping, pointing up "
    "and east\",\"6\":\"vertical, pointing east\",\"11\":\"sloping, pointing down "
    "and south\",\"7\":\"vertical, pointing south\",\"9\":\"vertical, pointing "
    "west\",\"14\":\"horizontal, pointing down\",\"4\":\"sloping, pointing up and "
    "north\",\"10\":\"sloping, pointing down and east\",\"13\":\"sloping, pointing "
    "down and west\",\"8\":\"vertical, pointing north\",\"3\":\"sloping, pointing "
    "up and south\",\"5\":\"sloping, pointing up and west\",\"12\":\"sloping, "
    "pointing down and north\"},\"settings\":{\"sloping_plane_classes_maximum_a"
    "ngle\":70.0,\"plane_classification_method\":2,\"sloping_plane_classes_mini"
    "mum_angle\":10.0}}"
};

// Grouping and sorting of point attributes for visualization purposes
const MetaDataItemInfo RDB_RIEGL_POINT_ATTRIBUTE_GROUPS = {
    /* name        */ "riegl.point_attribute_groups",
    /* title       */ "Point Attribute Groups",
    /* description */ "Grouping and sorting of point attributes for visualization purposes",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"patternProperties\":{\"^.*$\":{\"items\":{\"description\":\"Point attribute "
    "full name or name pattern (perl regular expression "
    "syntax)\",\"type\":\"string\"},\"description\":\"Each field of the object "
    "represents a point attribute group and holds a list of point "
    "attributes, where the field name is the group name.\",\"minItems\":1,\"typ"
    "e\":\"array\"}},\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"desc"
    "ription\":\"Grouping and sorting of point attributes for visualization "
    "purposes\",\"additionalProperties\":false,\"type\":\"object\",\"title\":\"Point "
    "Attribute Groups\"}"
    ,
    /* example: */
    "{\"Coordinates/Vectors\":[\"riegl.xyz\",\"riegl.range\",\"riegl.theta\",\"riegl"
    ".phi\"],\"Other "
    "Attributes\":[\"riegl.selected\",\"riegl.visible\"],\"Secondary "
    "Attributes\":[\"riegl.mirror_facet\",\"riegl.waveform_available\"],\"Primary"
    " Attributes\":[\"riegl.reflectance\",\"riegl.amplitude\",\"riegl.deviation\"]"
    ",\"Time\":[\"riegl.timestamp\"]}"
};

// Details about point cloud files
const MetaDataItemInfo RDB_RIEGL_POINTCLOUD_INFO = {
    /* name        */ "riegl.pointcloud_info",
    /* title       */ "Point Cloud Information",
    /* description */ "Details about point cloud files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Details about point cloud files\",\"$schema\":\"http://jso"
    "n-schema.org/draft-04/schema#\",\"type\":\"object\",\"properties\":{\"comments"
    "\":{\"description\":\"Comments\",\"type\":\"string\"},\"project\":{\"description\":"
    "\"Project "
    "name\",\"type\":\"string\"},\"field_of_application\":{\"description\":\"Field of"
    " application\",\"type\":\"string\",\"enum\":[\"unknown\",\"SLS\",\"TLS\",\"KLS\",\"MLS"
    "\",\"ULS\",\"ALS\",\"BLS\",\"ILS\"]}},\"title\":\"Point Cloud Information\"}"
    ,
    /* example: */
    "{\"comments\":\"Line 3\",\"project\":\"Campaign "
    "4\",\"field_of_application\":\"ALS\"}"
};

// Estimated position and orientation information
const MetaDataItemInfo RDB_RIEGL_POSE_ESTIMATION = {
    /* name        */ "riegl.pose_estimation",
    /* title       */ "Pose Estimation",
    /* description */ "Estimated position and orientation information",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"orientation\"],\"title\":\"Pose Estimation\",\"$schema\":\"http:"
    "//json-schema.org/draft-04/schema#\",\"description\":\"Estimated position "
    "and orientation information as measured by GNSS, IMU or inclination se"
    "nsors\",\"type\":\"object\",\"properties\":{\"barometric_height_amsl\":{\"descri"
    "ption\":\"Altitude determined based on the atmospheric pressure "
    "according to the standard atmosphere laws [m].\",\"type\":\"number\"},\"posi"
    "tion\":{\"required\":[\"coordinate_1\",\"coordinate_2\",\"coordinate_3\",\"horiz"
    "ontal_accuracy\",\"vertical_accuracy\",\"crs\"],\"description\":\"Position "
    "coordinates and position accuracy values as measured by GNSS in the "
    "specified Coordinate Reference System (CRS)\",\"type\":\"object\",\"properti"
    "es\":{\"vertical_accuracy\":{\"description\":\"Vertical accuracy [m]\",\"type\""
    ":\"number\",\"minimum\":0,\"exclusiveMinimum\":true},\"horizontal_accuracy\":{"
    "\"description\":\"Horizontal accuracy [m]\",\"type\":\"number\",\"minimum\":0,\"e"
    "xclusiveMinimum\":true},\"coordinate_2\":{\"description\":\"Coordinate 2 as "
    "defined by axis 2 of the specified CRS (e.g., Y, Longitude)\",\"type\":\"n"
    "umber\"},\"crs\":{\"required\":[\"epsg\"],\"description\":\"Global Coordinate "
    "Reference System\",\"type\":\"object\",\"properties\":{\"wkt\":{\"description\":\""
    "\\\"Well-Known Text\\\" string, OGC WKT dialect (see http://www.opengeospa"
    "tial.org/standards/wkt-crs)\",\"type\":\"string\"},\"epsg\":{\"description\":\"E"
    "PSG code\",\"type\":\"integer\",\"minimum\":0}}},\"coordinate_1\":{\"description"
    "\":\"Coordinate 1 as defined by axis 1 of the specified CRS (e.g., X, "
    "Latitude)\",\"type\":\"number\"},\"coordinate_3\":{\"description\":\"Coordinate "
    "3 as defined by axis 3 of the specified CRS (e.g., Z, Altitude)\",\"type"
    "\":\"number\"}}},\"orientation\":{\"required\":[\"roll\",\"pitch\",\"yaw\",\"roll_ac"
    "curacy\",\"pitch_accuracy\",\"yaw_accuracy\"],\"description\":\"Orientation "
    "values and orientation accuracies, measured with IMU or inclination se"
    "nsors.\",\"type\":\"object\",\"properties\":{\"yaw_accuracy\":{\"description\":\"Y"
    "aw angle accuracy [deg]\",\"type\":\"number\",\"minimum\":0,\"exclusiveMinimum"
    "\":true},\"pitch\":{\"description\":\"Pitch angle about scanner Y-axis [deg]"
    "\",\"type\":\"number\",\"maximum\":360,\"minimum\":-360},\"yaw\":{\"description\":\""
    "Yaw angle about scanner Z-axis [deg]\",\"type\":\"number\",\"maximum\":360,\"m"
    "inimum\":-360},\"roll\":{\"description\":\"Roll angle about scanner X-axis ["
    "deg]\",\"type\":\"number\",\"maximum\":360,\"minimum\":-360},\"pitch_accuracy\":{"
    "\"description\":\"Pitch angle accuracy [deg]\",\"type\":\"number\",\"minimum\":0"
    ",\"exclusiveMinimum\":true},\"roll_accuracy\":{\"description\":\"Roll angle "
    "accuracy "
    "[deg]\",\"type\":\"number\",\"minimum\":0,\"exclusiveMinimum\":true}}}}}"
    ,
    /* example: */
    "{\"barometric_height_amsl\":386.7457796227932,\"position\":{\"vertical_accu"
    "racy\":1.3314999341964722,\"horizontal_accuracy\":0.810699999332428,\"coor"
    "dinate_2\":15.645033406,\"crs\":{\"wkt\":\"GEOGCS[\\\"WGS84 / Geographic\\\",DAT"
    "UM[\\\"WGS84\\\",SPHEROID[\\\"WGS84\\\",6378137.000,298.257223563,AUTHORITY[\\\""
    "EPSG\\\",\\\"7030\\\"]],AUTHORITY[\\\"EPSG\\\",\\\"6326\\\"]],PRIMEM[\\\"Greenwich\\\",0"
    ".0000000000000000,AUTHORITY[\\\"EPSG\\\",\\\"8901\\\"]],UNIT[\\\"Degree\\\",0.0174"
    "5329251994329547,AUTHORITY[\\\"EPSG\\\",\\\"9102\\\"]],AXIS[\\\"Latitude\\\",NORTH"
    "],AXIS[\\\"Longitude\\\",EAST],AUTHORITY[\\\"EPSG\\\",\\\"4979\\\"]]\",\"epsg\":4979}"
    ",\"coordinate_1\":48.655799473,\"coordinate_3\":362.7124938964844},\"orient"
    "ation\":{\"yaw_accuracy\":1.0094337839368757,\"pitch\":1.509153024827064,\"y"
    "aw\":101.87293630292045,\"roll\":3.14743073066123,\"pitch_accuracy\":0.0094"
    "33783936875745,\"roll_accuracy\":0.009433783936875745}}"
};

// Details on position and orientation sensors
const MetaDataItemInfo RDB_RIEGL_POSE_SENSORS = {
    /* name        */ "riegl.pose_sensors",
    /* title       */ "Pose Sensors",
    /* description */ "Details on position and orientation sensors",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"gyroscope\",\"accelerometer\",\"magnetic_field_sensor\"],\"tit"
    "le\":\"Pose Sensors\",\"$schema\":\"http://json-schema.org/draft-04/schema#\""
    ",\"description\":\"Details on position and orientation sensors\",\"type\":\"o"
    "bject\",\"properties\":{\"gyroscope\":{\"required\":[\"unit\",\"x_axis\",\"y_axis\""
    ",\"z_axis\",\"offset\",\"origin\",\"relative_nonlinearity\"],\"description\":\"Gy"
    "roscope "
    "details\",\"type\":\"object\",\"properties\":{\"offset\":{\"description\":\"Value "
    "to be subtracted from raw measurement "
    "values\",\"$ref\":\"#/definitions/vector\"},\"unit\":{\"description\":\"Unit of "
    "raw data and calibration values, 1 LSB in rad/s\",\"type\":\"number\",\"mini"
    "mum\":0,\"exclusiveMinimum\":true},\"origin\":{\"description\":\"Sensor origin"
    " in SOCS [m] at frame angle = "
    "0\",\"$ref\":\"#/definitions/vector\"},\"x_axis\":{\"description\":\"Sensitive X"
    " axis of sensor at frame angle = "
    "0\",\"$ref\":\"#/definitions/vector\"},\"z_axis\":{\"description\":\"Sensitive Z"
    " axis of sensor at frame angle = 0\",\"$ref\":\"#/definitions/vector\"},\"re"
    "lative_nonlinearity\":{\"description\":\"Relative nonlinearity, dimensionl"
    "ess\",\"$ref\":\"#/definitions/vector\"},\"y_axis\":{\"description\":\"Sensitive"
    " Y axis of sensor at frame angle = 0\",\"$ref\":\"#/definitions/vector\"}}}"
    ",\"magnetic_field_sensor\":{\"required\":[\"unit\",\"x_axis\",\"y_axis\",\"z_axis"
    "\",\"offset\",\"fixed\",\"relative_nonlinearity\"],\"description\":\"Magnetic "
    "Field Sensor "
    "details\",\"type\":\"object\",\"properties\":{\"offset\":{\"description\":\"Value "
    "to be subtracted from raw measurement "
    "values\",\"$ref\":\"#/definitions/vector\"},\"unit\":{\"description\":\"Unit of "
    "raw data and calibration values, 1 LSB in nT\",\"type\":\"number\",\"minimum"
    "\":0,\"exclusiveMinimum\":true},\"fixed\":{\"description\":\"Distortion of "
    "magnetic field caused by non-rotating scanner part\",\"$ref\":\"#/definiti"
    "ons/vector\"},\"x_axis\":{\"description\":\"Sensitive X axis of sensor at "
    "frame angle = "
    "0\",\"$ref\":\"#/definitions/vector\"},\"z_axis\":{\"description\":\"Sensitive Z"
    " axis of sensor at frame angle = 0\",\"$ref\":\"#/definitions/vector\"},\"re"
    "lative_nonlinearity\":{\"description\":\"Relative nonlinearity, dimensionl"
    "ess\",\"$ref\":\"#/definitions/vector\"},\"y_axis\":{\"description\":\"Sensitive"
    " Y axis of sensor at frame angle = 0\",\"$ref\":\"#/definitions/vector\"}}}"
    ",\"accelerometer\":{\"required\":[\"unit\",\"x_axis\",\"y_axis\",\"z_axis\",\"offse"
    "t\",\"origin\",\"relative_nonlinearity\"],\"description\":\"Accelerometer "
    "details\",\"type\":\"object\",\"properties\":{\"offset\":{\"description\":\"Value "
    "to be subtracted from raw measurement "
    "values\",\"$ref\":\"#/definitions/vector\"},\"unit\":{\"description\":\"Unit of "
    "raw data and calibration values, 1 LSB in 9.81 m/s\\u00b2\",\"type\":\"numb"
    "er\",\"minimum\":0,\"exclusiveMinimum\":true},\"origin\":{\"description\":\"Sens"
    "or origin in SOCS [m] at frame angle = "
    "0\",\"$ref\":\"#/definitions/vector\"},\"x_axis\":{\"description\":\"Sensitive X"
    " axis of sensor at frame angle = "
    "0\",\"$ref\":\"#/definitions/vector\"},\"z_axis\":{\"description\":\"Sensitive Z"
    " axis of sensor at frame angle = 0\",\"$ref\":\"#/definitions/vector\"},\"re"
    "lative_nonlinearity\":{\"description\":\"Relative nonlinearity, dimensionl"
    "ess\",\"$ref\":\"#/definitions/vector\"},\"y_axis\":{\"description\":\"Sensitive"
    " Y axis of sensor at frame angle = 0\",\"$ref\":\"#/definitions/vector\"}}}"
    "},\"definitions\":{\"vector\":{\"items\":{\"description\":\"Index 0=X, 1=Y, 2=Z"
    " component\",\"type\":\"number\"},\"minItems\":3,\"type\":\"array\",\"maxItems\":3}"
    "}}"
    ,
    /* example: */
    "{\"gyroscope\":{\"offset\":[-50.92609786987305,146.15643310546875,62.43272"
    "78137207],\"unit\":0.00014544410805683583,\"origin\":[0.026900000870227814"
    ",-0.03999999910593033,-0.08950000256299973],\"x_axis\":[-121.19555664062"
    "5,0.8219714164733887,0.2313031703233719],\"z_axis\":[0.555869996547699,1"
    "19.22135162353516,0.467585027217865],\"relative_nonlinearity\":[2.888176"
    "311444113e-07,1.06274164579645e-07,-1.7186295080634935e-39],\"y_axis\":["
    "-0.440765917301178,-0.7897399663925171,119.5894775390625]},\"magnetic_f"
    "ield_sensor\":{\"offset\":[-23812.052734375,5606.57666015625,2493.28125],"
    "\"unit\":91.74311828613281,\"fixed\":[-1576.010498046875,1596.081787109375"
    ",0.0],\"x_axis\":[-0.011162743903696537,-2.315962774446234e-05,0.0001681"
    "8844596855342],\"z_axis\":[0.00041987866279669106,7.876977906562388e-05,"
    "0.011407104320824146],\"relative_nonlinearity\":[0.0,0.0,0.0],\"y_axis\":["
    "0.00027888521435670555,-0.011427424848079681,-5.204829722060822e-05]},"
    "\"accelerometer\":{\"offset\":[-733.3636474609375,58.969032287597656,1060."
    "2550048828125],\"unit\":6.666666740784422e-05,\"origin\":[0.02690000087022"
    "7814,-0.03999999910593033,-0.08950000256299973],\"x_axis\":[-15008.12304"
    "6875,56.956390380859375,-60.5175666809082],\"z_axis\":[1.639882206916809"
    ",15166.744140625,-116.99742889404297],\"relative_nonlinearity\":[0.0,0.0"
    ",0.0],\"y_axis\":[-7.027288913726807,-44.12333679199219,14952.3701171875"
    "]}}"
};

// Laser pulse position modulation used for MTA resolution
const MetaDataItemInfo RDB_RIEGL_PULSE_POSITION_MODULATION = {
    /* name        */ "riegl.pulse_position_modulation",
    /* title       */ "Pulse Position Modulation",
    /* description */ "Laser pulse position modulation used for MTA resolution",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"length\",\"num_mod_ampl\",\"pulse_interval\"],\"title\":\"Pulse "
    "Position Modulation\",\"$schema\":\"http://json-schema.org/draft-04/schema"
    "#\",\"description\":\"Laser pulse position modulation used for MTA resolut"
    "ion\",\"type\":\"object\",\"properties\":{\"pulse_interval\":{\"items\":{\"type\":\""
    "number\",\"minimum\":0},\"description\":\"Explicit table of the pulse "
    "position modulation used for MTA resolution. Table gives times between"
    " successive laser pulses in "
    "seconds.\",\"type\":\"array\"},\"length\":{\"description\":\"Length of code\",\"ty"
    "pe\":\"integer\",\"maximum\":255,\"minimum\":0},\"num_mod_ampl\":{\"description\""
    ":\"Number of different modulation amplitudes (2: binary modulation)\",\"t"
    "ype\":\"integer\",\"maximum\":255,\"minimum\":0},\"code_phase_mode\":{\"descript"
    "ion\":\"0: no synchronization, 1: toggle between 2 phases, 2: increment "
    "with phase_increment\",\"type\":\"integer\",\"maximum\":255,\"minimum\":0},\"pha"
    "se_step\":{\"description\":\"Step width in phase of modulation code from "
    "line to line\",\"type\":\"integer\",\"maximum\":255,\"minimum\":0}}}"
    ,
    /* example: */
    "{\"pulse_interval\":[2.759375e-06,2.759375e-06,2.759375e-06,2.759375e-06"
    ",2.821875e-06,2.759375e-06,2.759375e-06,2.821875e-06,2.759375e-06,2.82"
    "1875e-06,2.821875e-06,2.759375e-06,2.759375e-06,2.821875e-06,2.821875e"
    "-06,2.821875e-06,2.821875e-06,2.821875e-06,2.759375e-06,2.759375e-06,2"
    ".759375e-06,2.821875e-06,2.821875e-06,2.759375e-06,2.821875e-06,2.8218"
    "75e-06,2.821875e-06,2.759375e-06,2.821875e-06,2.759375e-06,2.821875e-0"
    "6],\"length\":31,\"num_mod_ampl\":2,\"code_phase_mode\":2,\"phase_step\":5}"
};

// Statistics about target distance wrt. SOCS origin
const MetaDataItemInfo RDB_RIEGL_RANGE_STATISTICS = {
    /* name        */ "riegl.range_statistics",
    /* title       */ "Range Statistics",
    /* description */ "Statistics about target distance wrt. SOCS origin",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"minimum\",\"average\",\"maximum\",\"std_dev\"],\"title\":\"Range S"
    "tatistics\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"descri"
    "ption\":\"Statistics about target distance wrt. SOCS origin\",\"type\":\"obj"
    "ect\",\"properties\":{\"std_dev\":{\"description\":\"Standard "
    "deviation\",\"type\":\"number\"},\"maximum\":{\"description\":\"Maximum "
    "value\",\"type\":\"number\"},\"minimum\":{\"description\":\"Minimum "
    "value\",\"type\":\"number\"},\"average\":{\"description\":\"Average "
    "value\",\"type\":\"number\"}}}"
    ,
    /* example: */
    "{\"std_dev\":24.349,\"maximum\":574.35,\"minimum\":0.919,\"average\":15.49738}"
};

// Receiver Internals
const MetaDataItemInfo RDB_RIEGL_RECEIVER_INTERNALS = {
    /* name        */ "riegl.receiver_internals",
    /* title       */ "Receiver Internals",
    /* description */ "Receiver Internals",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Receiver Internals\",\"$schema\":\"http://json-schema.org/draft-"
    "04/schema#\",\"description\":\"Receiver Internals\",\"type\":\"object\",\"proper"
    "ties\":{\"a\":{\"items\":{\"type\":\"number\"},\"minItems\":1,\"type\":\"array\",\"max"
    "Items\":256,\"description\":\"Amplitude [dB]\"},\"si\":{\"description\":\"Start "
    "index (hw_start)\",\"type\":\"number\",\"maximum\":255,\"minimum\":0},\"ns\":{\"de"
    "scription\":\"Number of samples\",\"type\":\"integer\",\"maximum\":4095,\"minimu"
    "m\":0},\"sr\":{\"exclusiveMinimum\":true,\"type\":\"number\",\"minimum\":0,\"descr"
    "iption\":\"Sample rate [Hz]\"},\"mw\":{\"exclusiveMinimum\":true,\"type\":\"numb"
    "er\",\"maximum\":4095,\"minimum\":0,\"description\":\"Maximum "
    "weight\"},\"ex\":{\"description\":\"DEPRECATED, use "
    "'riegl.exponential_decomposition' "
    "instead\",\"type\":\"object\"},\"nt\":{\"description\":\"Number of traces\",\"type"
    "\":\"integer\",\"maximum\":255,\"minimum\":0},\"t\":{\"additionalProperties\":fal"
    "se,\"type\":\"object\",\"patternProperties\":{\"^[0-9]+$\":{\"description\":\"one"
    " field per channel, field name is channel index\",\"$ref\":\"#/definitions"
    "/fp\"}}},\"tbl\":{\"items\":{\"$ref\":\"#/definitions/fp_table\"},\"minItems\":1,"
    "\"type\":\"array\",\"description\":\"various internal data\"}},\"definitions\":{"
    "\"fp_table\":{\"required\":[\"ch\",\"tc\",\"nx\",\"ny\",\"tv\"],\"desription\":\"scanne"
    "r internal "
    "data\",\"type\":\"object\",\"properties\":{\"nx\":{\"description\":\"number of x e"
    "ntries\",\"min\":1,\"type\":\"integer\",\"max\":2048},\"ch\":{\"description\":\"chan"
    "nel number\",\"min\":0,\"type\":\"integer\",\"max\":255},\"ny\":{\"description\":\"n"
    "umber of y entries\",\"min\":1,\"type\":\"integer\",\"max\":2048},\"tv\":{\"minIte"
    "ms\":1,\"items\":{\"oneOf\":[{\"$ref\":\"#/definitions/fp_table_row\"},{\"type\":"
    "\"number\"}]},\"type\":\"array\",\"maxItems\":2048},\"tc\":{\"description\":\"table"
    " data type code\",\"min\":0,\"type\":\"integer\",\"max\":255}}},\"fp\":{\"required"
    "\":[\"s\",\"w\"],\"description\":\"Fingerprint values\",\"type\":\"object\",\"proper"
    "ties\":{\"s\":{\"items\":{\"items\":{\"type\":\"number\"},\"minItems\":1,\"type\":\"ar"
    "ray\",\"maxItems\":4096},\"minItems\":1,\"type\":\"array\",\"maxItems\":256},\"w\":"
    "{\"items\":{\"items\":{\"type\":\"number\"},\"minItems\":5,\"type\":\"array\",\"maxIt"
    "ems\":5},\"minItems\":1,\"type\":\"array\",\"maxItems\":256}}},\"fp_table_row\":{"
    "\"minItems\":1,\"items\":{\"type\":\"number\"},\"type\":\"array\",\"maxItems\":2048}"
    "}}"
    ,
    /* example: */
    "{\"a\":[-1.55],\"si\":48,\"ns\":400,\"sr\":7959997000.0,\"mw\":31,\"nt\":128,\"t\":{"
    "\"0\":{\"s\":[[1.23,4.56],[7.89,0.12]],\"w\":[[78,86,126,134,31],[78,86,126,"
    "134,31]]},\"1\":{\"s\":[[1.23,4.56],[7.89,0.12]],\"w\":[[78,86,126,134,31],["
    "78,86,126,134,31]]}},\"tbl\":[{\"nx\":5,\"ch\":0,\"ny\":2,\"tv\":[[1,2,3,4,5],[1"
    ".1,2.2,3.3,4.4,5.5]],\"tc\":1}]}"
};

// Lookup table for reflectance calculation based on amplitude and range
const MetaDataItemInfo RDB_RIEGL_REFLECTANCE_CALCULATION = {
    /* name        */ "riegl.reflectance_calculation",
    /* title       */ "Reflectance Calculation Table",
    /* description */ "Lookup table for reflectance calculation based on amplitude and range",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"delta\",\"content\"],\"title\":\"Reflectance Calculation Table"
    "\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"description\":\"L"
    "ookup table for reflectance calculation based on amplitude and "
    "range\",\"type\":\"object\",\"properties\":{\"delta\":{\"description\":\"Delta "
    "between table entries [m], first entry is at range = 0 m\",\"type\":\"numb"
    "er\"},\"content\":{\"items\":{\"type\":\"number\"},\"description\":\"Correction "
    "value [dB] to be added to the "
    "amplitude\",\"minItems\":1,\"type\":\"array\",\"maxItems\":2000}}}"
    ,
    /* example: */
    "{\"delta\":0.150918,\"content\":[-33.01]}"
};

// Range-dependent and scan-angle-dependent correction of reflectance reading
const MetaDataItemInfo RDB_RIEGL_REFLECTANCE_CORRECTION = {
    /* name        */ "riegl.reflectance_correction",
    /* title       */ "Near-Range Reflectance Correction",
    /* description */ "Range-dependent and scan-angle-dependent correction of reflectance reading",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"ranges_m\",\"line_angles_deg\",\"reflectance_correction_db\"]"
    ",\"title\":\"Near-range reflectance correction\",\"$schema\":\"http://json-sc"
    "hema.org/draft-04/schema#\",\"description\":\"Range-dependent and "
    "scan-angle-dependent correction of reflectance reading\",\"type\":\"object"
    "\",\"properties\":{\"reflectance_correction_db\":{\"items\":{\"items\":{\"descri"
    "ption\":\"columns (each value corresponds to an "
    "angle)\",\"type\":\"number\"},\"description\":\"rows (each array corresponds "
    "to a range)\",\"type\":\"array\"},\"description\":\"Near range reflectance "
    "correction in dB as a function of range over angle\",\"type\":\"array\"},\"l"
    "ine_angles_deg\":{\"items\":{\"type\":\"number\"},\"description\":\"Angle [deg]\""
    ",\"type\":\"array\"},\"ranges_m\":{\"items\":{\"type\":\"number\"},\"description\":\""
    "Range [m]\",\"type\":\"array\"}}}"
    ,
    /* example: */
    "{\"reflectance_correction_db\":[[0.8,0.7,0.6,0.5,0.4,0.3,0.2,0.1,0.05,0."
    "01],[0.8,0.7,0.6,0.5,0.4,0.3,0.2,0.1,0.05,0.01],[0.8,0.7,0.6,0.5,0.4,0"
    ".3,0.2,0.1,0.05,0.01],[0.8,0.7,0.6,0.5,0.4,0.3,0.2,0.1,0.05,0.01]],\"li"
    "ne_angles_deg\":[0.0,0.5,1.0,1.5,1.0,2.0,2.5,3.0,3.5,4.0],\"ranges_m\":[0"
    ".0,1.0,2.0,3.0]}"
};

// Scan pattern description
const MetaDataItemInfo RDB_RIEGL_SCAN_PATTERN = {
    /* name        */ "riegl.scan_pattern",
    /* title       */ "Scan Pattern",
    /* description */ "Scan pattern description",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Scan pattern description\",\"$schema\":\"http://json-schem"
    "a.org/draft-04/schema#\",\"definitions\":{\"program\":{\"required\":[\"name\"],"
    "\"description\":\"Measurement program\",\"type\":\"object\",\"properties\":{\"las"
    "er_prr\":{\"description\":\"Laser Pulse Repetition Rate [Hz]\",\"type\":\"numb"
    "er\",\"minimum\":0,\"exclusiveMinimum\":false},\"name\":{\"description\":\"Name "
    "of measurement program\",\"type\":\"string\"}}}},\"properties\":{\"rectangular"
    "\":{\"required\":[\"phi_start\",\"phi_stop\",\"phi_increment\",\"theta_start\",\"t"
    "heta_stop\",\"theta_increment\"],\"description\":\"Rectangular Field Of View"
    " Scan Pattern\",\"type\":\"object\",\"properties\":{\"phi_start\":{\"description"
    "\":\"Start phi angle in SOCS [deg]\",\"type\":\"number\",\"maximum\":360.0,\"min"
    "imum\":0.0},\"program\":{\"$ref\":\"#/definitions/program\"},\"theta_increment"
    "\":{\"description\":\"Increment of theta angle in SOCS [deg]\",\"type\":\"numb"
    "er\",\"maximum\":90.0,\"minimum\":0.0},\"theta_stop\":{\"description\":\"Stop "
    "theta angle in SOCS [deg]\",\"type\":\"number\",\"maximum\":180.0,\"minimum\":0"
    ".0},\"theta_start\":{\"description\":\"Start theta angle in SOCS [deg]\",\"ty"
    "pe\":\"number\",\"maximum\":180.0,\"minimum\":0.0},\"phi_increment\":{\"descript"
    "ion\":\"Increment of phi angle in SOCS [deg]\",\"type\":\"number\",\"maximum\":"
    "90.0,\"minimum\":0.0},\"phi_stop\":{\"description\":\"Stop phi angle in SOCS "
    "[deg]\",\"type\":\"number\",\"maximum\":720.0,\"minimum\":0.0}}},\"segments\":{\"r"
    "equired\":[\"list\"],\"description\":\"Segmented Line Scan Pattern\",\"type\":\""
    "object\",\"properties\":{\"program\":{\"$ref\":\"#/definitions/program\"},\"list"
    "\":{\"items\":{\"required\":[\"start\",\"stop\",\"increment\"],\"description\":\"Lin"
    "e Scan Segment\",\"type\":\"object\",\"properties\":{\"increment\":{\"descriptio"
    "n\":\"Increment of angle in SOCS [deg]\",\"type\":\"number\",\"maximum\":90.0,\""
    "minimum\":0.0},\"stop\":{\"description\":\"Stop angle in SOCS [deg]\",\"type\":"
    "\"number\",\"maximum\":720.0,\"minimum\":0.0},\"start\":{\"description\":\"Start "
    "angle in SOCS [deg]\",\"type\":\"number\",\"maximum\":360.0,\"minimum\":0.0}}},"
    "\"type\":\"array\"}}},\"line\":{\"required\":[\"start\",\"stop\",\"increment\"],\"des"
    "cription\":\"Line Scan Pattern\",\"type\":\"object\",\"properties\":{\"program\":"
    "{\"$ref\":\"#/definitions/program\"},\"increment\":{\"description\":\"Increment"
    " of angle in SOCS [deg]\",\"type\":\"number\",\"maximum\":90.0,\"minimum\":0.0}"
    ",\"stop\":{\"description\":\"Stop angle in SOCS [deg]\",\"type\":\"number\",\"max"
    "imum\":720.0,\"minimum\":0.0},\"start\":{\"description\":\"Start angle in SOCS"
    " "
    "[deg]\",\"type\":\"number\",\"maximum\":360.0,\"minimum\":0.0}}}},\"title\":\"Scan"
    " Pattern\"}"
    ,
    /* example: */
    "{\"rectangular\":{\"phi_start\":45.0,\"program\":{\"laser_prr\":100000.0,\"name"
    "\":\"High Speed\"},\"theta_increment\":0.04,\"theta_stop\":130.0,\"theta_start"
    "\":30.0,\"phi_increment\":0.04,\"phi_stop\":270.0}}"
};

// Details about laser shot files
const MetaDataItemInfo RDB_RIEGL_SHOT_INFO = {
    /* name        */ "riegl.shot_info",
    /* title       */ "Shot Information",
    /* description */ "Details about laser shot files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Details about laser shot files\",\"$schema\":\"http://json"
    "-schema.org/draft-04/schema#\",\"type\":\"object\",\"properties\":{\"shot_file"
    "\":{\"required\":[\"file_extension\"],\"type\":\"object\",\"properties\":{\"file_u"
    "uid\":{\"description\":\"File's Universally Unique Identifier (RFC "
    "4122)\",\"type\":\"string\"},\"file_extension\":{\"description\":\"Shot file "
    "extension, without the leading dot\",\"type\":\"string\"}}}},\"title\":\"Shot "
    "Information\"}"
    ,
    /* example: */
    "{\"shot_file\":{\"file_uuid\":\"26a00815-67c0-4bff-8fe8-c577378fe663\",\"file"
    "_extension\":\"sodx\"}}"
};

// Point filters applied in addition to the application-defined filters
const MetaDataItemInfo RDB_RIEGL_STORED_FILTERS = {
    /* name        */ "riegl.stored_filters",
    /* title       */ "Stored Filters",
    /* description */ "Point filters applied in addition to the application-defined filters",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"activated\",\"filters\"],\"title\":\"Stored filters\",\"$schema\""
    ":\"http://json-schema.org/draft-04/schema#\",\"description\":\"Point "
    "filters applied in addition to the application-defined filters\",\"type\""
    ":\"object\",\"properties\":{\"activated\":{\"description\":\"Apply ('true') or "
    "ignore ('false') all filters\",\"type\":\"boolean\"},\"filters\":{\"items\":{\"r"
    "equired\":[\"activated\",\"title\",\"description\",\"filter\"],\"description\":\"P"
    "oint filter definition\",\"type\":\"object\",\"properties\":{\"activated\":{\"de"
    "scription\":\"Apply ('true') or ignore ('false') this "
    "filter\",\"type\":\"boolean\"},\"title\":{\"description\":\"A short filter title"
    " (e.g. for display in a selection "
    "list)\",\"type\":\"string\"},\"filter\":{\"description\":\"The RDB filter string"
    " to apply (e.g. when reading points or index), details see "
    "documentation of function "
    "select()\",\"type\":\"string\"},\"description\":{\"description\":\"A brief "
    "description of the filter (e.g. for display in a "
    "tooltip)\",\"type\":\"string\"}}},\"description\":\"List of point "
    "filters\",\"type\":\"array\"}}}"
    ,
    /* example: */
    "{\"activated\":true,\"filters\":[{\"activated\":false,\"title\":\"Ignore "
    "uncertain points from MTA "
    "resolution\",\"filter\":\"riegl.mta_uncertain_point == "
    "0\",\"description\":\"Ignore points with uncertain MTA zone "
    "assignment\"},{\"activated\":false,\"title\":\"Ignore points below dynamic "
    "trigger level\",\"filter\":\"riegl.dyntrig_uncertain_point == "
    "0\",\"description\":\"Ignore points with an echo signal amplitude below "
    "the dynamic trigger\"},{\"activated\":false,\"title\":\"Ignore points "
    "outside outer AABB\",\"filter\":\"riegl.point_outside_aabb_bocs == "
    "0\",\"description\":\"Ignore points that are outside the outer AABB in "
    "BOCS\"},{\"activated\":false,\"title\":\"Ignore points inside inner "
    "AABB\",\"filter\":\"riegl.point_inside_aabb_bocs == "
    "0\",\"description\":\"Ignore points that are inside the inner AABB in "
    "BOCS\"}]}"
};

// Details of major system components like lidar sensors, cameras and navigation devices
const MetaDataItemInfo RDB_RIEGL_SYSTEM_DESCRIPTION = {
    /* name        */ "riegl.system_description",
    /* title       */ "System Description",
    /* description */ "Details of major system components like lidar sensors, cameras and navigation devices",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"$class\",\"version\",\"author\",\"timestamp\",\"system\"],\"title\""
    ":\"System Description\",\"$schema\":\"http://json-schema.org/draft-04/schem"
    "a#\",\"description\":\"Details of major system components like lidar "
    "sensors, cameras and navigation "
    "devices\",\"type\":\"object\",\"properties\":{\"system\":{\"description\":\"The "
    "actual system description, details see documentation of RIEGL System "
    "Description\",\"type\":\"object\"},\"$class\":{\"description\":\"Object class na"
    "me\",\"type\":\"string\",\"enum\":[\"Document\"]},\"author\":{\"description\":\"Name"
    " of the author that created the "
    "document\",\"type\":\"string\"},\"version\":{\"description\":\"Document format "
    "version\",\"type\":\"string\"},\"timestamp\":{\"description\":\"Date and time of"
    " creation (e.g. 2019-06-19T13:32:10+02:00)\",\"type\":\"string\"}}}"
    ,
    /* example: */
    "{\"system\":{\"details\":\"see documentation of RIEGL System "
    "Description\"},\"$class\":\"Document\",\"author\":\"RIEGL LMS GmbH, "
    "Austria\",\"version\":\"1.2.1\",\"timestamp\":\"2022-09-30T11:56:26+00:00\"}"
};

// Conversion of background radiation raw values to temperatures in °C
const MetaDataItemInfo RDB_RIEGL_TEMPERATURE_CALCULATION = {
    /* name        */ "riegl.temperature_calculation",
    /* title       */ "Temperature Calculation Table",
    /* description */ "Conversion of background radiation raw values to temperatures in °C",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Temperature Calculation Table\",\"$schema\":\"http://json-schema"
    ".org/draft-04/schema#\",\"description\":\"Conversion of background "
    "radiation raw values to temperatures in \\u00b0C\",\"type\":\"object\",\"prop"
    "erties\":{\"InGaAs\":{\"description\":\"Conversion table for InGaAs channel\""
    ",\"$ref\":\"#/definitions/conversion_table\"},\"InGaAs_Si_Difference\":{\"des"
    "cription\":\"Conversion table for InGaAs - Si difference\",\"$ref\":\"#/defi"
    "nitions/conversion_table\"},\"Si\":{\"description\":\"Conversion table for "
    "Si channel\",\"$ref\":\"#/definitions/conversion_table\"}},\"definitions\":{\""
    "conversion_table\":{\"required\":[\"value\",\"temperature\"],\"type\":\"object\","
    "\"properties\":{\"temperature\":{\"items\":{\"type\":\"number\"},\"description\":\""
    "Temperature [\\u00b0C]\",\"type\":\"array\"},\"value\":{\"items\":{\"type\":\"numbe"
    "r\"},\"description\":\"LSB [1]\",\"type\":\"array\"}}}}}"
    ,
    /* example: */
    "{\"InGaAs\":{\"temperature\":[307.22196722535614,309.1153478247277,311.118"
    "8086915047,313.10025350480055,315.2137946389828,317.2172555057597,319."
    "2207163725366,321.2021611858325,323.3157023200148],\"value\":[0.0,64.000"
    "97659230323,128.0019531846065,192.0029297769097,256.0039063692129,320."
    "00488296151616,384.0058595538194,448.0068361461226,512.0078127384259]}"
    ",\"InGaAs_Si_Difference\":{\"temperature\":[1749.977111117893,1749.9771111"
    "17893,1749.977111117893,1749.977111117893,1749.977111117893,1749.97711"
    "1117893,1744.7813348796044,1681.9971312601092,1622.3944822534868],\"val"
    "ue\":[1000.0,1100.090029602954,1200.04425183874,1300.1342814416948,1400"
    ".0885036774805,1500.0427259132668,1600.1327555162209,1700.086977752006"
    "5,1800.0411999877924]},\"Si\":{\"temperature\":[546.300048828125,548.81640"
    "51212026,551.3143938500972,554.0144257850053,556.604252334815,559.2124"
    "464488079,561.8022729986177,564.4104671126105,567.0002936624203],\"valu"
    "e\":[0.0,64.00097659230323,128.0019531846065,192.0029297769097,256.0039"
    "063692129,320.00488296151616,384.0058595538194,448.0068361461226,512.0"
    "078127384259]}}"
};

// Base of timestamps (epoch)
const MetaDataItemInfo RDB_RIEGL_TIME_BASE = {
    /* name        */ "riegl.time_base",
    /* title       */ "Time Base",
    /* description */ "Base of timestamps (epoch)",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"epoch\",\"source\"],\"title\":\"Time Base\",\"$schema\":\"http://j"
    "son-schema.org/draft-04/schema#\",\"description\":\"Base of timestamps (ep"
    "och)\",\"type\":\"object\",\"properties\":{\"source\":{\"description\":\"Timestamp"
    " source\",\"type\":\"string\",\"enum\":[\"unknown\",\"RTC\",\"GNSS\"]},\"system\":{\"d"
    "escription\":\"Time system (time standard)\",\"type\":\"string\",\"enum\":[\"unk"
    "nown\",\"UTC\",\"GPS\"]},\"epoch\":{\"description\":\"Date and time of timestamp"
    " '0' as proposed by RFC 3339 (e.g. "
    "2015-10-27T00:00:00+01:00).\",\"type\":\"string\"}}}"
    ,
    /* example: */
    "{\"source\":\"GNSS\",\"system\":\"UTC\",\"epoch\":\"2015-10-27T00:00:00+00:00\"}"
};

// Details about position+orientation files
const MetaDataItemInfo RDB_RIEGL_TRAJECTORY_INFO = {
    /* name        */ "riegl.trajectory_info",
    /* title       */ "Trajectory Information",
    /* description */ "Details about position+orientation files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"time_interval\",\"navigation_frame\"],\"title\":\"Trajectory I"
    "nformation\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"descr"
    "iption\":\"Details about position+orientation files\",\"type\":\"object\",\"pr"
    "operties\":{\"navigation_frame\":{\"description\":\"Navigation frame (NED: "
    "North-East-Down, ENU: East-North-Up)\",\"type\":\"string\",\"enum\":[\"unknown"
    "\",\"NED\",\"ENU\"]},\"location\":{\"description\":\"Project location, e.g. city"
    "/state/country\",\"type\":\"string\"},\"time_interval\":{\"required\":[\"minimum"
    "\",\"average\",\"maximum\",\"std_dev\"],\"description\":\"Time interval statisti"
    "cs\",\"type\":\"object\",\"properties\":{\"std_dev\":{\"description\":\"Standard "
    "deviation of intervals "
    "[s]\",\"type\":\"number\"},\"maximum\":{\"description\":\"Maximum time interval "
    "[s]\",\"type\":\"number\"},\"minimum\":{\"description\":\"Minimum time interval "
    "[s]\",\"type\":\"number\"},\"average\":{\"description\":\"Average time interval "
    "[s]\",\"type\":\"number\"}}},\"settings\":{\"description\":\"Settings used to "
    "calculate the trajectory (descriptive "
    "text)\",\"type\":\"string\"},\"device\":{\"description\":\"Navigation device, "
    "e.g. "
    "name/type/serial\",\"type\":\"string\"},\"project\":{\"description\":\"Project "
    "name\",\"type\":\"string\"},\"company\":{\"description\":\"Company "
    "name\",\"type\":\"string\"},\"field_of_application\":{\"description\":\"Field of"
    " application\",\"type\":\"string\",\"enum\":[\"unknown\",\"SLS\",\"TLS\",\"KLS\",\"MLS"
    "\",\"ULS\",\"ALS\",\"BLS\",\"ILS\"]},\"software\":{\"description\":\"Software that "
    "calculated the trajectory (this may be the same or different software "
    "than the one that created the file)\",\"type\":\"string\"}}}"
    ,
    /* example: */
    "{\"navigation_frame\":\"NED\",\"location\":\"Horn\",\"time_interval\":{\"std_dev\""
    ":5.51e-07,\"maximum\":0.005004883,\"minimum\":0.00500032,\"average\":0.00500"
    "053},\"settings\":\"default\",\"device\":\"IMU Model 12/1, Serial# "
    "12345\",\"project\":\"Campaign 3\",\"company\":\"RIEGL "
    "LMS\",\"field_of_application\":\"MLS\",\"software\":\"Navigation Software "
    "XYZ\"}"
};

// Trigger-Timestamping-Unit/IP configuration
const MetaDataItemInfo RDB_RIEGL_TTIP_CONFIGURATION = {
    /* name        */ "riegl.ttip_configuration",
    /* title       */ "TTIP Configuration",
    /* description */ "Trigger-Timestamping-Unit/IP configuration",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"ttip_version\",\"num_channel\",\"ext_channel\",\"ext_signal\",\""
    "ext_delay\",\"ext_subdivider\",\"ext_bitmask\",\"dmi_incr\",\"dmi_min_time\",\"d"
    "mi_max_time\",\"dmi_dist_per_tick\",\"channel\",\"output_descr\",\"input_descr"
    "\",\"output_usage\",\"input_usage\",\"out_polarity\",\"out_duration\",\"out_inte"
    "rval\",\"out_delay\",\"out_num_pulses\",\"in_polarity\",\"in_min_duration\",\"in"
    "_max_duration\",\"in_max_delay\"],\"title\":\"TTIP Configuration\",\"$schema\":"
    "\"http://json-schema.org/draft-04/schema#\",\"description\":\"Trigger-Times"
    "tamping-Unit/IP configuration\",\"type\":\"object\",\"properties\":{\"in_polar"
    "ity\":{\"description\":\"0 .. positive edge, 1 .. negative edge\",\"type\":\"i"
    "nteger\",\"minimum\":0},\"num_channel\":{\"description\":\"number of "
    "input/output channels\",\"type\":\"integer\",\"minimum\":0},\"ext_subdivider\":"
    "{\"description\":\"reduces the frequency, default "
    "1\",\"type\":\"integer\",\"minimum\":0},\"dmi_min_time\":{\"description\":\"dmi, "
    "minimum time interval between trigger events [0.1 msec]\",\"type\":\"integ"
    "er\",\"minimum\":0},\"out_interval\":{\"description\":\"output pulse interval "
    "[0.1 msec]\",\"type\":\"integer\",\"minimum\":0},\"out_num_pulses\":{\"descripti"
    "on\":\"number of output pulses to be generated, 0 .. infinite\",\"type\":\"i"
    "nteger\",\"minimum\":0},\"in_min_duration\":{\"description\":\"input signals "
    "with smaller pulse durations are ignored [0.1 "
    "msec]\",\"type\":\"integer\",\"minimum\":0},\"dmi_incr\":{\"description\":\"dmi, "
    "increment in "
    "ticks\",\"type\":\"integer\"},\"dmi_max_time\":{\"description\":\"dmi, maximum "
    "time interval between trigger events [0.1 msec]\",\"type\":\"integer\",\"min"
    "imum\":0},\"out_delay\":{\"description\":\"output pulse initial delay after "
    "start [0.1 "
    "msec]\",\"type\":\"integer\",\"minimum\":0},\"ext_signal\":{\"description\":\"0 .."
    " use input signal, 1 .. use output signal of "
    "channel\",\"type\":\"integer\",\"minimum\":0},\"input_usage\":{\"description\":\"0"
    " .. deactivated, 1 .. just detecting and timestamping\",\"type\":\"integer"
    "\",\"minimum\":0},\"in_max_delay\":{\"description\":\"maximum delay to output "
    "pulse before fake event is generated [0.1 msec], zero indicates that "
    "no fake events are generated\",\"type\":\"integer\",\"minimum\":0},\"ext_bitma"
    "sk\":{\"description\":\"defines which of the internal pulse generators are"
    " to be started\",\"type\":\"integer\",\"minimum\":0},\"out_duration\":{\"descrip"
    "tion\":\"output pulse duration [0.1 msec]\",\"type\":\"integer\",\"minimum\":0}"
    ",\"in_max_duration\":{\"description\":\"stops measurement of pulse duration"
    " of input signal [0.1 msec]\",\"type\":\"integer\",\"minimum\":0},\"ext_delay\""
    ":{\"description\":\"external trigger, time delay [0.1 "
    "msec]\",\"type\":\"integer\",\"minimum\":0},\"output_usage\":{\"description\":\"0 "
    ".. no output, 1 .. output derived from internal clock, 2 .. output "
    "derived from dmi, 3 .. output derived from external signal, 4 .. "
    "output static low, 5 .. output static "
    "high\",\"type\":\"integer\",\"minimum\":0},\"channel\":{\"description\":\"ID of "
    "input/output channel\",\"type\":\"integer\",\"minimum\":0},\"input_descr\":{\"de"
    "scription\":\"descriptive "
    "string\",\"type\":\"string\"},\"out_polarity\":{\"description\":\"0 .. positive "
    "edge, 1 .. negative edge\",\"type\":\"integer\",\"minimum\":0},\"output_descr\""
    ":{\"description\":\"descriptive "
    "string\",\"type\":\"string\"},\"dmi_dist_per_tick\":{\"description\":\"dmi, "
    "distance per tick, just informative "
    "[m]\",\"type\":\"number\"},\"ext_channel\":{\"description\":\"ID of channel used"
    " as external trigger input, 32 indicates none\",\"type\":\"integer\",\"minim"
    "um\":0},\"ttip_version\":{\"description\":\"following "
    "main.sub.ss.sss\",\"type\":\"integer\",\"minimum\":0}}}"
    ,
    /* example: */
    "{\"in_polarity\":0,\"num_channel\":9,\"ext_subdivider\":1,\"dmi_min_time\":0,\""
    "out_interval\":10000,\"out_num_pulses\":1,\"in_min_duration\":0,\"dmi_incr\":"
    "0,\"dmi_max_time\":0,\"out_delay\":0,\"ext_signal\":0,\"input_usage\":1,\"in_ma"
    "x_delay\":9990,\"ext_bitmask\":0,\"out_duration\":300,\"in_max_duration\":100"
    "00,\"ext_delay\":0,\"output_usage\":1,\"channel\":0,\"input_descr\":\"Port 1 - "
    "Exposure\",\"out_polarity\":0,\"output_descr\":\"Port 1 - "
    "Trigger\",\"dmi_dist_per_tick\":0.0,\"ext_channel\":32,\"ttip_version\":1}"
};

// Details about vertex file
const MetaDataItemInfo RDB_RIEGL_VERTEX_INFO = {
    /* name        */ "riegl.vertex_info",
    /* title       */ "Vertex Information",
    /* description */ "Details about vertex file",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Details about vertex file\",\"$schema\":\"http://json-sche"
    "ma.org/draft-04/schema#\",\"type\":\"object\",\"properties\":{\"vertex_file\":{"
    "\"required\":[\"file_extension\"],\"type\":\"object\",\"properties\":{\"file_uuid"
    "\":{\"description\":\"File's Universally Unique Identifier (RFC "
    "4122)\",\"type\":\"string\"},\"file_extension\":{\"description\":\"Vertex file "
    "extension, without the leading "
    "dot\",\"type\":\"string\"}}}},\"title\":\"Vertex Information\"}"
    ,
    /* example: */
    "{\"vertex_file\":{\"file_uuid\":\"51534d95-d71f-4f36-ae1a-3e63a21fd1c7\",\"fi"
    "le_extension\":\"vtx\"}}"
};

// Details about the voxels contained in the file
const MetaDataItemInfo RDB_RIEGL_VOXEL_INFO = {
    /* name        */ "riegl.voxel_info",
    /* title       */ "Voxel Information",
    /* description */ "Details about the voxels contained in the file",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Voxel Information\",\"oneOf\":[{\"required\":[\"size\",\"voxel_origi"
    "n\",\"voxel_type\"],\"additionalProperties\":false,\"properties\":{\"shape_thr"
    "esholds\":{\"$ref\":\"#/definitions/shape_thresholds\"},\"voxel_type\":{\"$ref"
    "\":\"#/definitions/voxel_type\"},\"size\":{\"description\":\"Size of voxels in"
    " file coordinate system.\",\"oneOf\":[{\"$ref\":\"#/definitions/voxel_size\"}"
    ",{\"$ref\":\"#/definitions/voxel_size_cubic\"}]},\"voxel_origin\":{\"$ref\":\"#"
    "/definitions/voxel_origin_enum\"}}},{\"required\":[\"reference_point\",\"siz"
    "e_llcs\",\"size\",\"voxel_origin\",\"voxel_type\"],\"additionalProperties\":fal"
    "se,\"properties\":{\"reference_point\":{\"items\":{\"type\":\"number\",\"maximum\""
    ":180,\"minimum\":-180},\"description\":\"Point in WGS84 geodetic decimal "
    "degree (EPSG:4326) that was used to compute the projection distortion "
    "parameters. The coefficient order is latitude, longitude. Only voxels "
    "with corresponding geo_tag, voxel_size and reference_point can be "
    "reliably processed together. This entry is available for voxel files "
    "in projected CRS only.\",\"minItems\":2,\"type\":\"array\",\"maxItems\":2},\"vox"
    "el_type\":{\"$ref\":\"#/definitions/voxel_type\"},\"voxel_origin\":{\"oneOf\":["
    "{\"$ref\":\"#/definitions/voxel_origin_enum\"},{\"description\":\"The base "
    "point of the voxel grid. Used together with <tt>voxel_size</tt> and "
    "<tt>voxel_index</tt> to compute actual point coordinates.\",\"$ref\":\"#/d"
    "efinitions/voxel_origin_point\"}]},\"shape_thresholds\":{\"$ref\":\"#/defini"
    "tions/shape_thresholds\"},\"size_llcs\":{\"description\":\"Size of voxels in"
    " a locally levelled cartesian coordinate system (xyz). This is only "
    "used for voxels based on a map projection.\",\"$ref\":\"#/definitions/voxe"
    "l_size\"},\"size\":{\"description\":\"Size of voxels in file coordinate syst"
    "em.\",\"$ref\":\"#/definitions/voxel_size\"}}}],\"$schema\":\"http://json-sche"
    "ma.org/draft-04/schema#\",\"description\":\"Details about the voxels "
    "contained in the file\",\"type\":\"object\",\"definitions\":{\"voxel_origin_po"
    "int\":{\"items\":{\"type\":\"number\"},\"description\":\"Origin point for all "
    "voxel indices in voxel CRS.\",\"minItems\":3,\"type\":\"array\",\"maxItems\":3}"
    ",\"voxel_type\":{\"description\":\"Whether a point in a voxel represents "
    "its center or its centroid. If type is <tt>index</tt> there is no "
    "point but only an integer voxel index.\",\"enum\":[\"center\",\"centroid\",\"i"
    "ndex\"],\"default\":\"centroid\"},\"voxel_size_cubic\":{\"type\":\"number\",\"$ref"
    "\":\"#/definitions/edge_length\"},\"voxel_size\":{\"items\":{\"$ref\":\"#/defini"
    "tions/edge_length\"},\"description\":\"Size of voxels.\",\"minItems\":3,\"type"
    "\":\"array\",\"maxItems\":3},\"edge_length\":{\"description\":\"Length of voxel "
    "edge [m].\",\"type\":\"number\",\"minimum\":0,\"exclusiveMinimum\":true},\"shape"
    "_thresholds\":{\"description\":\"Thresholds used to compute the voxel's "
    "shape_id value.\",\"type\":\"object\",\"required\":[\"plane\",\"line\"],\"properti"
    "es\":{\"plane\":{\"exclusiveMaximum\":true,\"minimum\":0,\"exclusiveMinimum\":t"
    "rue,\"description\":\"If the smallest eigenvalue is smaller than the "
    "median eigenvalue * plane_threshold, the voxel is considered a "
    "plane.\",\"type\":\"number\",\"maximum\":1},\"line\":{\"description\":\"If the "
    "biggest eigenvalue is bigger than the median eigenvalue * "
    "line_threshold, the voxel is considered a line.\",\"type\":\"number\",\"mini"
    "mum\":1,\"exclusiveMinimum\":true}}},\"voxel_origin_enum\":{\"description\":\""
    "Defines whether the voxel's center or a corner is placed on CRS origin"
    " <tt>(0/0/0)</tt>.\",\"enum\":[\"center\",\"corner\"],\"default\":\"corner\"}}}"
    ,
    /* example: */
    "{\"reference_point\":[48,16],\"voxel_type\":\"centroid\",\"voxel_origin\":\"cor"
    "ner\",\"shape_thresholds\":{\"plane\":0.16,\"line\":6},\"size_llcs\":[0.5156575"
    "252891171,0.5130835356683303,0.5143705304787237],\"size\":[0.59716428347"
    "79395,0.5971642834779395,0.5143705304787237]}"
};

// Settings for waveform averaging
const MetaDataItemInfo RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS = {
    /* name        */ "riegl.waveform_averaging_settings",
    /* title       */ "Waveform Averaging Settings",
    /* description */ "Settings for waveform averaging",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"num_shots\",\"mta_zone\"],\"title\":\"Waveform Averaging Setti"
    "ngs\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"description\""
    ":\"Settings for waveform averaging\",\"type\":\"object\",\"properties\":{\"trim"
    "\":{\"description\":\"Percentage for robust averaging.\",\"type\":\"number\",\"m"
    "aximum\":0.5,\"minimum\":0,\"default\":0},\"num_shots\":{\"description\":\"Numbe"
    "r of consecutive shots to be used for averaging.\",\"type\":\"integer\",\"mi"
    "nimum\":1},\"mta_zone\":{\"description\":\"Fixed MTA zone for "
    "averaging.\",\"type\":\"integer\",\"minimum\":1}}}"
    ,
    /* example: */
    "{\"trim\":0.05,\"num_shots\":7,\"mta_zone\":1}"
};

// Details about waveform files
const MetaDataItemInfo RDB_RIEGL_WAVEFORM_INFO = {
    /* name        */ "riegl.waveform_info",
    /* title       */ "Waveform Information",
    /* description */ "Details about waveform files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"sample_block_file\",\"sample_data_files\"],\"title\":\"Wavefor"
    "m Information\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"de"
    "scription\":\"Details about waveform files\",\"type\":\"object\",\"properties\""
    ":{\"sample_block_file\":{\"required\":[\"file_extension\"],\"type\":\"object\",\""
    "properties\":{\"file_uuid\":{\"description\":\"File's Universally Unique "
    "Identifier (RFC "
    "4122)\",\"type\":\"string\"},\"file_extension\":{\"description\":\"Sample block "
    "file extension, without the leading dot\",\"type\":\"string\"}}},\"range_off"
    "set_waveform_samples_m\":{\"description\":\"Calibrated device specific "
    "range offset for waveform samples in meters.\",\"type\":\"number\"},\"sample"
    "_data_files\":{\"items\":{\"required\":[\"channel\",\"channel_name\",\"sample_in"
    "terval\",\"sample_bits\",\"laser_wavelength\",\"delta_st\",\"file_extension\"],"
    "\"type\":\"object\",\"properties\":{\"laser_wavelength\":{\"description\":\"Laser"
    " wavelength in meters (0 = unknown)\",\"type\":\"number\",\"minimum\":0,\"excl"
    "usiveMinimum\":false},\"sample_interval\":{\"description\":\"Sampling "
    "interval in seconds\",\"type\":\"number\",\"minimum\":0,\"exclusiveMinimum\":fa"
    "lse},\"channel\":{\"exclusiveMaximum\":false,\"minimum\":0,\"description\":\"Sa"
    "mple block channel number (255 = invalid)\",\"exclusiveMinimum\":false,\"t"
    "ype\":\"integer\",\"maximum\":255},\"channel_name\":{\"description\":\"Sample "
    "block channel "
    "name\",\"type\":\"string\"},\"file_extension\":{\"description\":\"Sample data "
    "file extension, without the leading dot\",\"type\":\"string\"},\"sample_bits"
    "\":{\"exclusiveMaximum\":false,\"minimum\":0,\"description\":\"Bitwidth of "
    "samples (e.g. 10 bit, 12 bit)\",\"exclusiveMinimum\":false,\"type\":\"intege"
    "r\",\"maximum\":32},\"file_uuid\":{\"description\":\"File's Universally Unique"
    " Identifier (RFC 4122)\",\"type\":\"string\"},\"delta_st\":{\"description\":\"re"
    "served\",\"type\":\"number\"}}},\"type\":\"array\"},\"range_offset_m\":{\"descript"
    "ion\":\"Calibrated device specific range offset for waveform analysis by"
    " system response fitting in meters.\",\"type\":\"number\"}}}"
    ,
    /* example: */
    "{\"sample_block_file\":{\"file_uuid\":\"93a03615-66c0-4bea-8ff8-c577378fe66"
    "0\",\"file_extension\":\"sbx\"},\"range_offset_waveform_samples_m \":7.283,\"s"
    "ample_data_files\":[{\"laser_wavelength\":0,\"sample_interval\":1.00503e-09"
    ",\"file_uuid\":\"da084413-e3e8-4655-a122-071de8490d8e\",\"channel_name\":\"hi"
    "gh_power\",\"file_extension\":\"sp0\",\"sample_bits\":12,\"channel\":0,\"delta_s"
    "t\":0},{\"laser_wavelength\":0,\"sample_interval\":1.00503e-09,\"file_uuid\":"
    "\"93585b5e-5ea9-43a1-947b-e7ba3be642d2\",\"channel_name\":\"low_power\",\"fil"
    "e_extension\":\"sp1\",\"sample_bits\":12,\"channel\":1,\"delta_st\":0},{\"laser_"
    "wavelength\":0,\"sample_interval\":1.00503e-09,\"file_uuid\":\"9d2298c4-1036"
    "-464f-b5cb-1cf8e517f3a0\",\"channel_name\":\"wwf\",\"file_extension\":\"sp5\",\""
    "sample_bits\":12,\"channel\":5,\"delta_st\":0}],\"range_offset_m\":3.1415}"
};

// Scanner settings for waveform output
const MetaDataItemInfo RDB_RIEGL_WAVEFORM_SETTINGS = {
    /* name        */ "riegl.waveform_settings",
    /* title       */ "Waveform Settings",
    /* description */ "Scanner settings for waveform output",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Scanner settings for waveform output\",\"$schema\":\"http:"
    "//json-schema.org/draft-04/schema#\",\"items\":{\"required\":[\"sbl_name\",\"e"
    "nabled\",\"channel_idx_mask\"],\"type\":\"object\",\"properties\":{\"enabled\":{\""
    "description\":\"Waveform output enabled\",\"type\":\"boolean\"},\"pass_ampl_gr"
    "eater\":{\"description\":\"Threshold for amplitude greater than "
    "[dB]\",\"type\":\"number\"},\"pass_dev_less\":{\"description\":\"Threshold for "
    "deviation less than "
    "[1]\",\"type\":\"integer\"},\"pass_rng_greater\":{\"description\":\"Threshold "
    "for range greater than "
    "[m]\",\"type\":\"number\"},\"sbl_name\":{\"description\":\"Name of sample block,"
    " e.g.: wfm, "
    "wwf\",\"type\":\"string\"},\"pass_rng_less\":{\"description\":\"Threshold for "
    "range less than "
    "[m]\",\"type\":\"number\"},\"pass_dev_greater\":{\"description\":\"Threshold for"
    " deviation greater than "
    "[1]\",\"type\":\"integer\"},\"pass_ampl_less\":{\"description\":\"Threshold for "
    "amplitude less than "
    "[dB]\",\"type\":\"number\"},\"channel_idx_mask\":{\"description\":\"Bit mask for"
    " channels which belong to sbl_name: Channel 0 = Bit0, Channel 1 = "
    "Bit1, ...\",\"type\":\"integer\"},\"smart_enabled\":{\"description\":\"Smart "
    "waveform output "
    "enabled\",\"type\":\"boolean\"},\"logic_expression\":{\"description\":\"Logic "
    "expression of smart waveforms "
    "filter\",\"type\":\"string\"}}},\"type\":\"array\",\"title\":\"Waveform Settings\"}"
    ,
    /* example: */
    "[{\"enabled\":true,\"pass_ampl_greater\":1.0,\"channel_idx_mask\":11,\"pass_r"
    "ng_greater\":9.27,\"sbl_name\":\"wfm\",\"pass_rng_less\":13.11,\"pass_ampl_les"
    "s\":5.0,\"smart_enabled\":true},{\"sbl_name\":\"wwf\",\"enabled\":false,\"channe"
    "l_idx_mask\":32}]"
};

// Window analysis data estimated from scandata and resulting filter parameters
const MetaDataItemInfo RDB_RIEGL_WINDOW_ANALYSIS = {
    /* name        */ "riegl.window_analysis",
    /* title       */ "Window Analysis",
    /* description */ "Window analysis data estimated from scandata and resulting filter parameters",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"result\",\"filter\",\"settings\"],\"title\":\"Window Analysis\",\""
    "$schema\":\"http://json-schema.org/draft-04/schema#\",\"description\":\"Wind"
    "ow analysis data estimated from scandata and resulting filter paramete"
    "rs\",\"type\":\"object\",\"properties\":{\"settings\":{\"required\":[\"range\",\"amp"
    "litude\"],\"type\":\"object\",\"properties\":{\"amplitude\":{\"required\":[\"sigma"
    "_factor\",\"additive_value\"],\"type\":\"object\",\"properties\":{\"sigma_factor"
    "\":{\"type\":\"number\"},\"additive_value\":{\"type\":\"number\"}}},\"range\":{\"req"
    "uired\":[\"sigma_factor\",\"additive_value\"],\"type\":\"object\",\"properties\":"
    "{\"sigma_factor\":{\"type\":\"number\"},\"additive_value\":{\"type\":\"number\"}}}"
    "}},\"filter\":{\"required\":[\"angle\",\"range_min\",\"range_max\",\"amplitude_ma"
    "x\"],\"type\":\"object\",\"properties\":{\"amplitude_max\":{\"items\":{\"type\":\"nu"
    "mber\"},\"description\":\"[dB]\",\"type\":\"array\"},\"angle\":{\"items\":{\"type\":\""
    "number\"},\"description\":\"[deg]\",\"type\":\"array\"},\"range_min\":{\"items\":{\""
    "type\":\"number\"},\"description\":\"[m]\",\"type\":\"array\"},\"range_max\":{\"item"
    "s\":{\"type\":\"number\"},\"description\":\"[m]\",\"type\":\"array\"}}},\"result\":{\""
    "required\":[\"angle\",\"range_mean\",\"range_sigma\",\"amplitude_mean\",\"amplit"
    "ude_sigma\",\"amplitude_offset\"],\"type\":\"object\",\"properties\":{\"range_me"
    "an\":{\"items\":{\"type\":\"number\"},\"description\":\"[m]\",\"type\":\"array\"},\"am"
    "plitude_mean\":{\"items\":{\"type\":\"number\"},\"description\":\"[dB]\",\"type\":\""
    "array\"},\"timestamp\":{\"items\":{\"type\":\"number\"},\"description\":\"[s]\",\"ty"
    "pe\":\"array\"},\"range_sigma\":{\"items\":{\"type\":\"number\"},\"description\":\"["
    "m]\",\"type\":\"array\"},\"angle\":{\"items\":{\"type\":\"number\"},\"description\":\""
    "[deg]\",\"type\":\"array\"},\"amplitude_sigma\":{\"items\":{\"type\":\"number\"},\"d"
    "escription\":\"[dB]\",\"type\":\"array\"},\"amplitude_offset\":{\"items\":{\"type\""
    ":\"number\"},\"description\":\"[dB]\",\"type\":\"array\"}}}}}"
    ,
    /* example: */
    "{\"settings\":{\"amplitude\":{\"sigma_factor\":4,\"additive_value\":1.0},\"rang"
    "e\":{\"sigma_factor\":8,\"additive_value\":0.1}},\"filter\":{\"amplitude_max\":"
    "[8.04,8.01,7.99,7.96,7.93,7.9,7.88,7.85,7.83,7.8,7.78],\"angle\":[14.9,1"
    "5.0,15.1,15.2,15.3,15.4,15.5,15.6,15.7,15.8,15.9],\"range_min\":[-0.208,"
    "-0.21,-0.212,-0.214,-0.216,-0.218,-0.219,-0.221,-0.223,-0.225,-0.227],"
    "\"range_max\":[0.424,0.425,0.426,0.427,0.428,0.428,0.429,0.43,0.431,0.43"
    "1,0.432]},\"result\":{\"range_mean\":[0.1105621,0.1079564,0.1087088,0.1067"
    "261,0.1054582,0.1090412,0.102871,0.1019044,0.1051523,0.1058445,0.10312"
    "61],\"amplitude_mean\":[5.347396,5.263155,5.224655,5.179926,5.097782,5.1"
    "16479,5.051756,4.983473,5.007885,5.002441,4.982],\"timestamp\":[408.4441"
    ",411.4443],\"range_sigma\":[0.01869652,0.02151435,0.01747969,0.01918765,"
    "0.01945776,0.01934862,0.01955329,0.02225589,0.02229977,0.01899122,0.02"
    "009433],\"angle\":[14.9,15.0,15.1,15.2,15.3,15.4,15.5,15.6,15.7,15.8,15."
    "9],\"amplitude_sigma\":[0.4272844,0.4298479,0.4236816,0.4283583,0.436235"
    "3,0.4315141,0.4373984,0.4472798,0.4346001,0.4345487,0.4540681],\"amplit"
    "ude_offset\":[1.9,1.9]}}"
};

// Correction parameters for window glass echoes
const MetaDataItemInfo RDB_RIEGL_WINDOW_ECHO_CORRECTION = {
    /* name        */ "riegl.window_echo_correction",
    /* title       */ "Window Echo Correction",
    /* description */ "Correction parameters for window glass echoes",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"amplitude\",\"range\",\"slices\"],\"title\":\"Window Echo Correc"
    "tion\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"description"
    "\":\"Correction parameters for window glass echoes\",\"type\":\"object\",\"pro"
    "perties\":{\"amplitude\":{\"required\":[\"minimum\",\"maximum\",\"entries\"],\"des"
    "cription\":\"Amplitude axis of correction "
    "table\",\"type\":\"object\",\"properties\":{\"entries\":{\"description\":\"Number "
    "of amplitude entries\",\"type\":\"integer\",\"minimum\":1},\"maximum\":{\"descri"
    "ption\":\"Maximum amplitude in "
    "dB\",\"type\":\"number\",\"minimum\":0.0},\"minimum\":{\"description\":\"Minimum "
    "amplitude in dB\",\"type\":\"number\",\"minimum\":0.0}}},\"range\":{\"required\":"
    "[\"minimum\",\"maximum\",\"entries\"],\"description\":\"Range axis of "
    "correction "
    "table\",\"type\":\"object\",\"properties\":{\"entries\":{\"description\":\"Number "
    "of range entries\",\"type\":\"integer\",\"minimum\":1},\"maximum\":{\"descriptio"
    "n\":\"Maximum range in m\",\"type\":\"number\",\"maximum\":2.0,\"minimum\":-2.0},"
    "\"minimum\":{\"description\":\"Minimum range in m\",\"type\":\"number\",\"maximum"
    "\":2.0,\"minimum\":-2.0}}},\"slices\":{\"items\":{\"required\":[\"amplitude\",\"ta"
    "ble\"],\"description\":\"Window echo correction parameter slice\",\"type\":\"o"
    "bject\",\"properties\":{\"amplitude\":{\"description\":\"Window echo amplitude"
    " of slice in dB\",\"type\":\"number\"},\"table\":{\"items\":{\"items\":{\"items\":{"
    "\"description\":\"Table cell (item 0: amplitude in dB, 1: range in m, 2: "
    "flags)\",\"type\":\"number\"},\"description\":\"Table column (= range "
    "axis)\",\"minItems\":3,\"type\":\"array\",\"maxItems\":3},\"description\":\"Table "
    "row (= amplitude "
    "axis)\",\"minItems\":1,\"type\":\"array\"},\"description\":\"Correction table "
    "(dimension defined by the 'amplitude' and 'range' "
    "objects)\",\"minItems\":1,\"type\":\"array\"}}},\"type\":\"array\"}}}"
    ,
    /* example: */
    "{\"amplitude\":{\"entries\":128,\"maximum\":20,\"minimum\":2},\"range\":{\"entrie"
    "s\":128,\"maximum\":1.5060822940732335,\"minimum\":-1.5060822940732335},\"sl"
    "ices\":[{\"amplitude\":1.5,\"table\":[[[6.23,0.3535,1]],[[5.54,0.72375,1]]]"
    "},{\"amplitude\":2.0,\"table\":[[[6.23,0.3535,1]],[[5.54,0.72375,1]]]}]}"
};

// Table of all meta data item details records
const MetaDataItemInfo* const RDB_META_DATA_ITEMS[] = {
    &RDB_RIEGL_ANGULAR_NOTCH_FILTER,
    &RDB_RIEGL_ATMOSPHERE,
    &RDB_RIEGL_BEAM_GEOMETRY,
    &RDB_RIEGL_CONTROL_OBJECT_CATALOG,
    &RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE,
    &RDB_RIEGL_DETECTION_PROBABILITY,
    &RDB_RIEGL_DEVICE,
    &RDB_RIEGL_DEVICE_GEOMETRY,
    &RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL,
    &RDB_RIEGL_DEVICE_OUTPUT_LIMITS,
    &RDB_RIEGL_DEVICES,
    &RDB_RIEGL_DYNTRIG,
    &RDB_RIEGL_ECHO_INFO,
    &RDB_RIEGL_EXPONENTIAL_DECOMPOSITION,
    &RDB_RIEGL_GAUSSIAN_DECOMPOSITION,
    &RDB_RIEGL_GEO_TAG,
    &RDB_RIEGL_GEOMETRIC_SCALE_FACTOR,
    &RDB_RIEGL_GEOREFERENCING_PARAMETERS,
    &RDB_RIEGL_ITEM_NAMES,
    &RDB_RIEGL_LICENSES,
    &RDB_RIEGL_MTA_SETTINGS,
    &RDB_RIEGL_NEAR_RANGE_CORRECTION,
    &RDB_RIEGL_NOISE_ESTIMATES,
    &RDB_RIEGL_NOTCH_FILTER,
    &RDB_RIEGL_PIXEL_INFO,
    &RDB_RIEGL_PLANE_PATCH_MATCHING,
    &RDB_RIEGL_PLANE_PATCH_STATISTICS,
    &RDB_RIEGL_PLANE_SLOPE_CLASS_INFO,
    &RDB_RIEGL_POINT_ATTRIBUTE_GROUPS,
    &RDB_RIEGL_POINTCLOUD_INFO,
    &RDB_RIEGL_POSE_ESTIMATION,
    &RDB_RIEGL_POSE_SENSORS,
    &RDB_RIEGL_PULSE_POSITION_MODULATION,
    &RDB_RIEGL_RANGE_STATISTICS,
    &RDB_RIEGL_RECEIVER_INTERNALS,
    &RDB_RIEGL_REFLECTANCE_CALCULATION,
    &RDB_RIEGL_REFLECTANCE_CORRECTION,
    &RDB_RIEGL_SCAN_PATTERN,
    &RDB_RIEGL_SHOT_INFO,
    &RDB_RIEGL_STORED_FILTERS,
    &RDB_RIEGL_SYSTEM_DESCRIPTION,
    &RDB_RIEGL_TEMPERATURE_CALCULATION,
    &RDB_RIEGL_TIME_BASE,
    &RDB_RIEGL_TRAJECTORY_INFO,
    &RDB_RIEGL_TTIP_CONFIGURATION,
    &RDB_RIEGL_VERTEX_INFO,
    &RDB_RIEGL_VOXEL_INFO,
    &RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS,
    &RDB_RIEGL_WAVEFORM_INFO,
    &RDB_RIEGL_WAVEFORM_SETTINGS,
    &RDB_RIEGL_WINDOW_ANALYSIS,
    &RDB_RIEGL_WINDOW_ECHO_CORRECTION
};
const size_t RDB_META_DATA_ITEM_COUNT(
    sizeof(RDB_META_DATA_ITEMS) / sizeof(RDB_META_DATA_ITEMS[0])
);

#endif // RDB_81EBCB65_FE94_471E_8D25_2B4D71CC91B1
